<!DOCTYPE html>
<html lang="en-US">

<head>
    {% block head %}
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="VTES Archon tournament check-in">
    <link rel="shortcut icon" href="{{ url_for('img', path='favicon.ico') }}">
    <link rel="stylesheet" href="{{ url_for('static', path='layout.css') }}">
    <script async src="{{ url_for('static', path='checkin.js') }}" type="module"></script>
    <title>Tournament Check-in</title>
    {% endblock %}
</head>

<body>
    <div class="container text-center" id="contentContainer" data-code="{{ code }}">
        <h1 id="title">Check-in for: {{ name }}</h1>
        <p class="mt-4">
            <strong>This QR-Code is not a link: you cannot just scan it!</strong>
        </p>
        <p>
            Log into the Archon (https://archon.krcg.org). <br>
            Use the tournament's page <strong>check-in button</strong> to scan.
        </p>
    </div>
</body>

</html>