{% extends "layout.html.j2" %}

{% block content %}
<div class="row">
    <nav id="contentNav" class="navbar d-block col-xl-4">
        <div class="sticky-top z-1">
            <h3>Contents</h3>
            <ul class="navbar-nav navbar-nav-scroll">
                <li class="nav-item fw-bold">
                    <a class="nav-link" href="#introduction-and-terms">
                        Introduction and terms
                    </a>
                </li>
                <li class="nav-item fw-bold">
                    <a class="nav-link" href="#purpose-and-scope">
                        Purpose and scope
                    </a>
                </li>
                <li class="nav-item fw-bold">
                    <a class="nav-link" href="#standards-of-conduct">
                        Standards of conduct
                    </a>
                </li>
                <li class="nav-item fw-bold">
                    <a class="nav-link" href="#procedures">
                        Procedures
                    </a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#contact">
                        Contact
                    </a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#confidentiality">
                        Confidentiality
                    </a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#origination-of-on-site-sanctions">
                        Origination of on-site sanctions
                    </a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#origination-of-independently-initiated-sanctions">
                        Origination of independently initiated sanctions
                    </a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#review-all-sanctions">
                        Review: all sanctions
                    </a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" href="#appeals">
                        Appeals
                    </a>
                </li>
                <li class="nav-item fw-bold">
                    <a class="nav-link" href="#sanctions">
                        Sanctions
                    </a>
                </li>
            </ul>
        </div>
    </nav>
    <article class="col" data-bs-spy="scroll" data-bs-target="#contentNav">
        <h1>VEKN Code of Ethics</h1>
        <p><em>Version 1.5 — Effective 9 September 2019</em></p>
        <figure>
            <blockquote class="blockquote">
                “Be excellent to each other”
            </blockquote>
            <figcaption class="blockquote-footer">
                Bill S. Preston, Esq.
            </figcaption>
        </figure>
        <h2 id="introduction-and-terms">
            Introduction and terms
            <a href="#introduction-and-terms" rel="bookmark" class="link-secondary"><i class="bi bi-link-45deg"></i></a>
        </h2>
        <p>
            The <strong>Vampire: Elder Kindred Network (VEKN)</strong> is the Official Players’ Organization for the
            <strong>Vampire: The Eternal Struggle (VTES)</strong> card game.
        </p>
        <p>
            The VEKN is dedicated to the continued health of VTES. It encourages the game’s
            growth in popularity through embracing new players and supporting existing fans. The VEKN sanctions and
            regulates official VTES tournaments. It also maintains and publishes players’ tournament ratings and
            rankings.
        </p>
        <p>
            VEKN <strong>Princes</strong> are volunteers who promote VTES at the local level, coordinating tournaments
            and demonstrations. VEKN <strong>National Coordinators</strong> have similar roles to Princes, with a
            broader geographical boundaries and responsibility to approve tournament sanctioning in their region.
        </p>
        <p>
            <strong>Black Chantry Productions (BCP)</strong> is the publisher for VTES.
            BCP was established and is owned by 5 prominent VTES players. In August 2018, BCP accepted a proposal to
            internalize governance and administration functions from VEKN, resulting in
            the dissolution of the VEKN Inner Circle leadership group. BCP’s mission includes:
        </p>
        <ul>
            <li>revise existing cards to harmonize terminology and templates;</li>
            <li>develop new cards accepted for use in sanctioned tournament play;</li>
            <li>publish all official VTES cards, current and future (with contracted printing);</li>
            <li>maintain card rulings, card errata, tournament rules and judging guidelines;</li>
            <li>maintain the official player rating system;</li>
            <li>provide centralized, official fora for communication with the player base; and</li>
            <li>communicate with players through select social media sources.</li>
        </ul>
        <p>
            The <strong>VEKN Ethics Committee</strong> exists to consider allegations of unethical
            conduct (as defined in this code) involving members of VEKN. The committee is chaired by BCP’s
            <strong>Organized Play Coordinator</strong>.
        </p>
        <p>
            BCP shall designate three (3) VEKN members to sit on the Ethics Committee and a fourth
            (4th) VEKN member to act as an alternate for a sitting member as needed. Those members’ terms of service
            have no specified duration and they may step down at any time.
        </p>
        <p>
            The National Coordinator responsible for the region of a VEKN member alleged to violate this code shall be
            accorded equal participation and voting rights on the committee for the duration of an investigation
            relating to that incident, bringing the total number of individuals reviewing alleged violations to
            five (5).
        </p>
        <p>
            Alternate committee membership will be chosen if required <em>e.g.</em> in case of conflict of interest.
        </p>
        <h2 id="purpose-and-scope">
            Purpose and scope
            <a href="#purpose-and-scope" rel="bookmark" class="link-secondary"><i class="bi bi-link-45deg"></i></a>
        </h2>
        <p>
            The purpose of this code of ethics is to describe:
        </p>
        <ul>
            <li>
                standards for the conduct of all persons associated with activities and processes overseen by the VEKN;
            </li>
            <li>procedures by which alleged violations are to be investigated; and</li>
            <li>sanctions for conduct that does not conform to the described standards.</li>
        </ul>
        <p>
            This document is intended to be used by VEKN members, with a focus on event organisers.
        </p>
        <div class="alert alert-info" role="alert">
            <h4 id="note-on-the-use-of-the-word-sanction">
                Note on the use of the word “sanction”
                <a href="#note-on-the-use-of-the-word-sanction" rel="bookmark" class="link-secondary">
                    <i class="bi bi-link-45deg"></i></a>
            </h4>
            <p>
                This word has two distinctly different English definitions, both of which are used in this document:
            </p>
            <ul>
                <li>
                    <strong>(1)</strong> a threatened penalty for disobeying a law or rule (e.g., “The player received a
                    sanction in response to their violation of the ethics code”);
                </li>
                <li>
                    <strong>(2)</strong> official approval or permission (e.g., “this event is officially sanctioned by
                    VEKN”).
                </li>
            </ul>
        </div>
        <p>
            There is no direct relationship between this code of ethics and any criminal laws or procedures.
            The standards, procedures and sanctions concern only rights and privileges of VEKN membership.
            This includes, but is not limited to:
        </p>
        <ul>
            <li>the privilege of participating in tournaments and activities as a member of VEKN;</li>
            <li>maintenance of player rating under the VEKN player rating system; and</li>
            <li>
                access to information and infrastructure associated with VEKN
                (<em>i.e.</em>, VEKN web page and associated fora, VTES-related social media or messaging services
                administered by VEKN members, etc.)
            </li>
        </ul>
        <p>
            Every aspect of this code of ethics applies to all participants in activities overseen
            or sponsored by VEKN. It applies equally regardless of a person’s role within an event structure,
            organizational position or title within VEKN.
        </p>
        <h2 id="standards-of-conduct">
            Standards of conduct
            <a href="#standards-of-conduct" rel="bookmark" class="link-secondary"><i class="bi bi-link-45deg"></i></a>
        </h2>
        <div class="alert alert-primary" role="alert">
            <blockquote class="blockquote">
                <p>
                    VEKN is dedicated to ensuring player safety and to maintaining the upstanding reputation of
                    sanctioned events.
                </p>
                <p>
                    Judges and the Ethics Committee should have no hesitation in addressing code of ethics violations,
                    regardless of the effect on games in progress or the disruption to local play groups occurring after
                    sanctions are levied.
                </p>
                <p>
                    No response from those bodies could be more damaging than failing to appropriately address
                    incidences of intolerable behaviour from VEKN members.
                </p>
            </blockquote>
        </div>
        <p>
            The actions and behaviour of all persons associated with VEKN activities shall be:
        </p>
        <ul>
            <li>lawful in the region hosting the activity;</li>
            <li>in accordance with VEKN rules and regulations; and</li>
            <li>
                consistent with the principles of fair play, good sporting, honesty, and respect for the rights and
                well-being of others.
            </li>
        </ul>
        <p>
            The following is a list of examples of actions and behaviour that are considered unethical. It is not
            intended to be exhaustive. Any action or behaviour that is inconsistent with the principles of fair play,
            good sporting, honesty, or respect for the rights and well-of others may be considered to fall within the
            scope of this code of ethics.
        </p>
        <ul>
            <li>
                intentionally violating game rules or tournament regulations, particularly after being warned of this
                infraction at the current, or previous event(s);
            </li>
            <li>cheating by altering a deck during an event;</li>
            <li>deliberately misrepresenting VTES rules or a current game state;</li>
            <li>colluding to predetermine the winner of a game;</li>
            <li>
                failing to play to win as defined in
                <a href="/document/tournament-rules.html#H4-8-play-to-win">
                    VEKN Tournament Rules: 4.8. Play to Win</a>,
                particularly when the intent is to determine the winner of a game;
            </li>
            <li>participating in a tournament under a false name, or while under suspension;</li>
            <li>significant impairment or incapacity at an event due to alcohol or drug abuse;</li>
            <li>
                attempting to interfere with the rights or privileges of any VEKN member; such as by barring an active,
                unsuspended player from entering a sanctioned event;
            </li>
            <li>submitting a falsified tournament report;</li>
            <li>
                offering insult, slur, or other language that is derogatory towards an entire class of people based on
                their race, ethnicity, sex, gender, sexual orientation, disability, class, religion, age, or other
                self-identified or imputed identity to any person, present or not present, at the event;
            </li>
            <li>defaming the character of a VEKN member, either by slander or libel;</li>
            <li>
                making continued social advances towards a player despite clearly demonstrated lack of interest or
                initial rebuff;
            </li>
            <li>threatening bodily harm, physically intimidating or assaulting any person in the tournament venue;</li>
            <li>
                violating federal, state, or local laws while participating in activities that are associated with VEKN
            </li>
        </ul>
        <h2 id="procedures">
            Procedures
            <a href="#procedures" rel="bookmark" class="link-secondary"><i class="bi bi-link-45deg"></i></a>
        </h2>
        <h3 id="contact">
            Contact
            <a href="#contact" rel="bookmark" class="link-secondary"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Please contact
            <a href="mailto:orgplay@blackchantry" target="_blank" rel="noopener noreferrer">orgplay@blackchantry</a>.
            The committee will meet as needed via voice or video application or if the case presents in person.
            Submissions can be made electronically, and translation services will be a made available where applicable.
        </p>
        <h3 id="confidentiality">
            Confidentiality
            <a href="#confidentiality" rel="bookmark" class="link-secondary"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            The VEKN Ethics Committee will respect confidentiality requests for the purpose of
            protecting victims of abuse. At its discretion, it may publicly name a person about whom harassment
            complaints have been received, or privately warn third parties about them, if the committee believe that
            doing so will increase the safety of VEKN or the general public. The committee will not name harassment
            victims without their affirmative consent.
        </p>
        <h3 id="origination-of-on-site-sanctions">
            Origination of on-site sanctions
            <a href="#origination-of-on-site-sanctions" rel="bookmark" class="link-secondary">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            On-site sanctions are reserved for clear, gross code of ethics violations which occur within an event and
            which merit penalty more severe than disqualification from that single event. Only a head judge may issue
            an on-site sanction. On-site sanctions must be noted in the tournament report.
        </p>
        <p>
            The player alleged of violating the code of ethics is immediately disqualified from the current event
            (see the <a href="{{ url_for('document_judges_guide') }}">Judges’ Guide</a> for disqualification
            processes) and is suspended from participating in further VEKN-sanctioned events, per
            <a href="/document/tournament-rules.html#H1-1-player-eligibility">
                VEKN Tournament Rules: 1.1. Player Eligibility</a>.
            The duration of an on-site sanction is 30 days and applies only to the nation in which it was issued.
        </p>
        <p>
            The head judge of the event (as defined in the tournament rules) must initiate a review of the sanction with
            the VEKN Ethics Committee within 5 calendar days of the incident, or its associated suspension is
            lifted. The judge will detail the circumstances leading to the sanction, recommend a duration based on
            the infraction’s severity and provide a list of witnesses to the incident.
        </p>
        <h3 id="origination-of-independently-initiated-sanctions">
            Origination of independently initiated sanctions
            <a href="#origination-of-independently-initiated-sanctions" rel="bookmark" class="link-secondary">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            The Ethics Committee may also independently initiate review for behaviour observed
            either inside or outside an event environment. This process should be exceedingly rare, but may be
            required to address egregious ethics violations occurring outside the purview of sanctioned events.
        </p>
        <h3 id="review-all-sanctions">
            Review: all sanctions
            <a href="#review-all-sanctions" rel="bookmark" class="link-secondary"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            All sanctions, regardless of origin:
        </p>
        <ul>
            <li>shall be reviewed by the Ethics Committee within 14 days of receipt;</li>
            <li>
                are lifted if the Ethics Committee review fails to complete review within 14 days, returning the player
                to active status;
            </li>
            <li>require a 3/5ths majority among the reviewers to be upheld;</li>
            <li>if not upheld in review, are lifted and the player is returned to active status.</li>
        </ul>
        <p>
            Any player alleged to have committed an ethics code violation will be interviewed as part of the review
            process and is allowed to provide their own list of witnesses for discrete incidents.
        </p>
        <p>
            In cases where a member of the Ethics Committee is under review for alleged misconduct, the alternate
            committee member shall replace the standing committee member until the Ethics Committee has completed review
            of all complaints relating to that individual.
        </p>
        <p>
            If a committee member is otherwise unable to fulfil their obligation to the
            committee (e.g., due to illness, emergency or any other obligations requiring their attention), the
            alternate will assume that member’s responsibilities until such time as the standing committee member is
            able to resume their role.
        </p>
        <h3 id="appeals">
            Appeals
            <a href="#appeals" rel="bookmark" class="link-secondary"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            There is no appeal process for suspension from VEKN activities. The
            review and approval described above constitute the entirety of the process associated with suspensions.
            The determination of the Ethics Committee is final.
        </p>
        <h2 id="sanctions">
            Sanctions
            <a href="#sanctions" rel="bookmark" class="link-secondary"><i class="bi bi-link-45deg"></i></a>
        </h2>
        <p>
            Sanctions levied by the Ethics Committee
            are applicable world-wide after being issued. The Ethics Committee will establish a duration for
            sanction during the review process, considering the referring judge’s recommendation and conforming to
            the limits outlined below.
        </p>
        <p>
            Sanctions fall within 3 levels of severity:
        </p>
        <ul>
            <li><strong>Standard suspension:</strong> the player
                is prohibited from participating in further VEKN-sanctioned events while suspended per
                <a href="/document/tournament-rules.html#H1-1-player-eligibility">
                    VEKN Tournament Rules: 1.1. Player Eligibility</a>.
                The duration of a suspension may range from the remainder of the original 30-day term,
                up to but not exceeding 18 months from the date of the incident.
                At the discretion of the Ethic Committee, suspended players may be denied access to all VEKN privileges
                (including website access) during their suspension.
            </li>
            <li><strong>Probation:</strong> the player retains all VEKN privileges while under
                probation, including participating in VEKN-sanctioned events. The duration of a probation may not exceed
                12 months. Any further ethics code violations with that term lead to a mandatory suspension of the
                player, with the remaining term of the probation added to the term of the subsequent suspension. A
                player may be placed on probation only once during their VEKN career.
            </li>
            <li>
                <strong>Ban:</strong> the player is permanently
                prohibited from participating in further VEKN-sanctioned events. They are removed from the VEKN Player
                Ratings system and may be denied access to fora and/or websites associated with VEKN activities.
            </li>
        </ul>
        <p>
            Players subject to sanction will be notified of results at the conclusion of the review process.
        </p>
        <p>
            Suspended VEKN members forfeit all organizational roles or offices (i.e., Prince, National Coordinator,
            Playtest Coordinator, Ethics Committee Member, etc.) for a period of time equal to twice the duration of
            suspension, unless otherwise unanimously determined by the Ethics Committee.
        </p>
        <p>
            There are no other VEKN-recognized probations, suspensions or bans. Tournament organizers and judges must
            allow all VEKN registered players in good standing to fairly participate in sanctioned events. Failure to
            conform to this requirement should be reported to VEKN and may lead to forfeiture of VEKN Prince status,
            invalidation of tournament results and sanctions as described above against the tournament organizer
            and/or head judge.
        </p>
        <p>
            A list of probationary, suspended and banned players is published on the VEKN forums
            at <a href="https://www.vekn.net" , target="_blank">www.vekn.net</a>.
        </p>
    </article>
</div>
{% endblock%}