{% extends "layout.html.j2" %}

{% block scripts %}
<script async src="{{ url_for('static', path='tournament_display.js') }}" type="module"></script>
{% endblock%}

{% block content %}
{%if cutoff%}
<div id="tournamentDisplay" data-tournament='{{ tournament | jsonable | tojson }}'
    data-cutoff='{{ cutoff | jsonable | tojson}}'></div>
{% else %}
<div id="tournamentDisplay" data-tournament='{{ tournament | jsonable | tojson }}'></div>
{% endif %}
{% endblock %}