{% extends "layout.html.j2" %}

{% block content %}
<div class="row">
    <nav id="contentNav" class="navbar d-block col-xl-4">
        <div class="sticky-top z-1">
            <h3>Contents</h3>
            <ul class="navbar-nav navbar-nav-scroll">
                <li class="nav-item fw-bold"><a class="nav-link" href="#H1-general-rules">
                        1. General VEKN Tournament Rules
                    </a></li>
                <li class=" nav-item"><a class="nav-link" href="#H1-1-player-eligibility">
                        1.1. Player Eligibility
                    </a></li>
                <li class=" nav-item"><a class="nav-link" href="#H1-2-necessary_tournament_materials">
                        1.2. Necessary Tournament Materials
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H1-3-wagering">
                        1.3. Wagering
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H1-4-taking-notes">
                        1.4. Taking Notes
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H1-5-electronic-devices">
                        1.5. Electronic Devices
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H1-6-publishing-event-information">
                        1.6. Publishing Event Information
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H1-7-document-updates">
                        1.7. Document Updates
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#H2-tournament-responsibilities">
                        2. Tournament Responsibilities
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H2-1-event-knowledge-responsibilities">
                        2.1. Event Knowledge Responsibilities
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H2-2-tournament-organizer-responsibilities">
                        2.2. Tournament Organizer Responsibilities
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H2-3-player-responsibilities">
                        2.3. Player Responsibilities
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H2-4-spectator-responsibilities">
                        2.4. Spectator Responsibilities
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H2-5-judge-responsibilities">
                        2.5. Judge Responsibilities
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H2-6-head-judge-responsibilities">
                        2.6. Head Judge Responsibilities
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H2-7-appeals-to-the-head-judge">
                        2.7. Appeals to the Head Judge
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H2-8-lengthy-rulings">
                        2.8. Lengthy Rulings
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H2-9-multi-judge-system">
                        2.9. Multi-Judge System
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#H3-tournament-mechanics">
                        3. Tournament Mechanics
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H3-1-round-structure">
                        3.1. Round Structure
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H3-2-pre-game-procedure">
                        3.2. Pre-Game Procedure
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H3-3-tardiness">
                        3.3. Tardiness
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H3-4-pre-game-procedure">
                        3.4. Pre-Game Procedure
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H3-5-conceding-games">
                        3.5. Conceding Games
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H3-6-intentional-draw">
                        3.6. Intentional Draw
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H3-7-determining-a-game-winner">
                        3.7. Determining a Game Winner
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#H4-tournament-game-rules">
                        4. Tournament Game Rules
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H4-1-cards-allowed">
                        4.1. Cards Allowed
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H4-2-card-interpretation">
                        4.2. Card Interpretation
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H4-3-new-releases">
                        4.3. New Releases
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H4-4-card-elevation-and-disposition">
                        4.4. Card Elevation and Disposition
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H4-5-proxy-cards">
                        4.5. Proxy Cards
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H4-6-card-sleeves">
                        4.6. Card Sleeves
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H4-7-locked-cards">
                        4.7. Locked Cards
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H4-8-play-to-win">
                        4.8. Play to Win
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H4-9-infinite-loops">
                        4.9. Infinite Loops
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#H5-tournament-violations">
                        5. Tournament violations
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H5-1-cheating">
                        5.1. Cheating
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H5-2-unsportsmanlike-conduct">
                        5.2. Unsportsmanlike Conduct
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H5-3-slow-play">
                        5.3. Slow Play
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H5-4-marked-cards">
                        5.4. Marked Cards
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#H6-constructed-tournament-rules">
                        6. Constructed Tournament Rules
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H6-1-constructed-formats">
                        6.1. Constructed formats
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H6-2-constructed-deck-size-limits">
                        6.2. Constructed Deck Size Limits
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H6-3-constructed-deck-registration">
                        6.3. Constructed Deck Registration
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#H7-limited-tournament-rules">
                        7. Limited Tournament Rules
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H7-1-limited-formats">
                        7.1. Limited Formats
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H7-2-general-limited-format-rules">
                        7.2. General Limited Format Rules
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H7-3-standard-sealed-deck-tournament-rules">
                        7.3. Standard Sealed Deck Tournament Rules
                    </a></li>
                <li class=" nav-item"><a class="nav-link" href="#H7-4-restricted-trade-tournament-rules">
                        7.4. Restricted Trade Tournament Rules
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H7-5-general-draft-tournament-rules">
                        7.5. General Draft Tournament Rules
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H7-6-booster-draft-procedure">
                        7.6. Booster Draft Procedure
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H7-7-table-draft-rochester-draft-procedure">
                        7.7. Table Draft (Rochester Draft) Procedure
                    </a></li>
                <li class=" nav-item"><a class="nav-link" href="#H7-8-mixed-draft-elder-draft-procedure">
                        7.8. Mixed Draft (Elder Draft) Procedure
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H7-9-restricted-format">
                        7.9. Restricted format
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#H8-vekn-sanctioning-rules">
                        8. VEKN Sanctioning Rules
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H8-1-sanctioning-deadline">
                        8.1. Sanctioning Deadline
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H8-2-sanctioned-tournament-advertising">
                        8.2. Sanctioned Tournament Advertising
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#H9-event-reporting-rules">
                        9. Event Reporting Rules
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H9-1-organizer-records">
                        9.1. Organizer Records
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H9-2-event-report-deadline">
                        9.2. Event Report Deadline
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H9-3-delinquent-tournaments">
                        9.3. Delinquent Tournaments
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H9-4-invalid-tournaments">
                        9.4. Invalid Tournaments
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H9-5-event-status-updates">
                        9.5. Event Status Updates
                    </a></li>
                <li class="nav-item"><a class="nav-link" href="#H9-6-mandatory-vekn-numbers">
                        9.6. Mandatory VEKN Numbers
                    </a></li>
                <li class="nav-item">
                    <a class="nav-link" href="#H9-7-tournament-reports-and-event-invitation-lists">
                        9.7. Tournament Reports and Event Invitation Lists
                    </a>
                </li>
                <li class=" nav-item"><a class="nav-link" href="#H9-8-non-open-vtes-events">
                        9.8. Non-Open VTES Events
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#Happendix-a-vekn-rating-ranking-systems">
                        Appendix A - VEKN Rating &amp; Ranking Systems
                    </a></li>
                <li class="nav-item fw-bold"><a class="nav-link" href="#Happendix-b-definition-of-terms">
                        Appendix B - Definition of Terms
                    </a></li>
            </ul>
        </div>
    </nav>
    <article class="col" data-bs-spy="scroll" data-bs-target="#contentNav">
        <h1>VEKN Tournament Rules</h1>

        <h2 id="H1-general-rules">1. General VEKN Tournament Rules
            <a class="link-secondary" rel="bookmark" href="#H1-general-rules"><i class="bi bi-link-45deg"></i></a>
        </h2>
        <p>
            The <strong>Vampire: Elder Kindred Network (VEKN)</strong> is the Official Players’ Organization for the
            <strong>Vampire: The Eternal Struggle (VTES)</strong> card game.
        </p>
        <h3 id="H1-1-player-eligibility">1.1. Player Eligibility
            <a class="link-secondary" rel="bookmark" href="#H1-1-player-eligibility">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Any player is eligible to participate in an open, non-invitational, VEKN-sanctioned tournament (for
            non-open tournaments, see <a href="#H9-8-non-open-vtes-events">9.8. Non-Open VTES Events</a>)
            except for the following:
        </p>
        <ul>
            <li>
                The tournament organizer of record (unless he or she is participating in an event that uses the
                Multi-Judge System; see <a href="#H2-9-multi-judge-system">2.9. Multi-Judge System</a>);
            </li>
            <li>
                The head judge and any other listed judges of record (exception: see
                <a href="#H2-9-multi-judge-system">2.9. Multi-Judge System</a>);
            </li>
            <li>Players currently suspended by the VEKN;</li>
            <li>
                Other players specifically prohibited from participation by VEKN or Black Chantry Productions policy.
            </li>
        </ul>
        <p>
            Any ineligible player participating in a VEKN-sanctioned tournament will be subject to the
            <a href="{{ url_for('document_judges_guide') }}">Judges' Guide</a> and further VEKN review.
        </p>
        <h3 id="H1-2-necessary_tournament_materials">1.2. Necessary Tournament Materials
            <a class="link-secondary" rel="bookmark" href="#H1-2-necessary_tournament_materials">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>Players must bring the following items to a tournament in order to participate:</p>
        <ul>
            <li>
                A visible and reliable method to maintain and record game information (counters for the Blood Bank, pen
                and paper to record deck information if required, and so on).
            </li>
            <li>
                A valid and unique VEKN number registered in the participant's name.<br>
                <strong>Note:</strong> New players must register for VEKN membership at their first tournament. Players
                may only have one VEKN number. Tournament organizers must report any player using more than one VEKN
                membership number.
            </li>
            <li>
                Any materials specifically required for a particular tournament format, as required by these rules
                or the tournament organizer.<br> <strong>Example:</strong> Players need to bring their assembled
                decks to Constructed tournaments.
            </li>
        </ul>
        <h3 id="H1-3-wagering">1.3. Wagering
            <a class="link-secondary" rel="bookmark" href="#H1-3-wagering"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>Players and tournament officials may not wager, ante, or bet on the outcome of any portion of a tournament.
        </p>
        <h3 id="H1-4-taking-notes">1.4. Taking Notes
            <a class="link-secondary" rel="bookmark" href="#H1-4-taking-notes"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Players are allowed to take written notes of their opponents' decks and activities, so long as doing so
            doesn't interfere with game play (especially the speed of play).
        </p>
        <h3 id="H1-5-electronic-devices">1.5. Electronic Devices
            <a class="link-secondary" rel="bookmark" href="#H1-5-electronic-devices">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            The head judge or tournament organizer may choose not to allow players to participate with electronic
            devices (such as cellular phones, pagers, and/or portable audio units) turned on.
        </p>
        <h3 id="H1-6-publishing-event-information">1.6. Publishing Event Information
            <a class="link-secondary" rel="bookmark" href="#H1-6-publishing-event-information">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Black Chantry Productions reserves the right to publish event information such as the contents of any
            player's deck as well as transcripts or video reproductions of any sanctioned tournament. The tournament
            organizer is also permitted to publish event information.
        </p>
        <h3 id="H1-7-document-updates">1.7. Document Updates
            <a class="link-secondary" rel="bookmark" href="#H1-7-document-updates"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            The VEKN reserves the right to alter these rules as well as the right to interpret, modify, clarify, or
            otherwise issue official changes to these rules, with or without prior notice.
        </p>
        <h2 id="H2-tournament-responsibilities">2. Tournament Responsibilities
            <a class="link-secondary" rel="bookmark" href="#H2-tournament-responsibilities">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <h3 id="H2-1-event-knowledge-responsibilities">2.1. Event Knowledge Responsibilities
            <a class="link-secondary" rel="bookmark" href="#H2-1-event-knowledge-responsibilities">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Competitors, judges, and organizers involved in sanctioned
            tournaments are responsible for knowing and following the most current version of the VEKN Tournament
            Rules and any other applicable regulatory documents, including the game rules and official errata.
        </p>
        <p>
            All new cards and game rules go immediately into effect for
            VEKN tournaments. Whenever a ruling is reversed or new errata is issued, the ruling reversal or errata
            doesn't go into effect for 30 days.
        </p>
        <h3 id="H2-2-tournament-organizer-responsibilities">2.2. Tournament Organizer Responsibilities
            <a class="link-secondary" rel="bookmark" href="#H2-2-tournament-organizer-responsibilities">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            The tournament organizer for an event is ultimately responsible
            for all tournament operations and event reporting for the event. The tournament organizer's
            responsibilities include, but are not limited to, the following:
        </p>
        <ul>
            <li>Selecting the site for the event</li>
            <li>Providing all materials to operate the event (product at Sealed Deck events, and so on)</li>
            <li>Retaining all tournament results for one full year after the event's completion</li>
            <li>Reporting to the VEKN of all event results, including winner, in a timely manner</li>
            <li>
                Staffing the event with appropriate personnel (including finding an appropriate head judge for the
                event)
            </li>
            <li>Advertising the tournament sufficiently in advance of the event date</li>
        </ul>
        <p>
            The tournament organizer may choose to delegate some or all of these responsibilities.
        </p>
        <h3 id="H2-3-player-responsibilities">2.3. Player Responsibilities
            <a class="link-secondary" rel="bookmark" href="#H2-3-player-responsibilities">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Players must follow the rules interpretations and guidelines
            for play set forth by the VEKN, the head judge, and other tournament officials. Players are expected to
            behave in a respectful and sportsmanlike manner at all times. Players who argue with the head judge or
            other tournament officials may be subject to the appropriate provisions of the
            <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a>.
            Players are not permitted to waive penalties on behalf of their opponents. The judge must ensure that
            the appropriate penalty, if any, is imposed.
        </p>
        <h3 id="H2-4-spectator-responsibilities">2.4. Spectator Responsibilities
            <a class="link-secondary" rel="bookmark" href="#H2-4-spectator-responsibilities">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            A spectator of a game is defined as any person other than a
            judge or an organizer who is not playing in that game. A player who is ousted from a game is considered
            a spectator for the remainder of the round. All spectators are expected to remain silent during the
            course of a game and are not permitted to communicate with players in any way while a game is in
            progress. Spectators who believe that they have observed rules violations should inform a judge, but
            they must not interfere with the game. Players have the right to request that any spectator not observe
            their game. All such requests must be made through a judge, who may grant or deny the request as he or
            she sees fit. The judge or organizer may choose to prohibit all specatators at any table(s) or round(s)
            of the tournament.
        </p>
        <h3 id="H2-5-judge-responsibilities">2.5. Judge Responsibilities
            <a class="link-secondary" rel="bookmark" href="#H2-5-judge-responsibilities">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            All judges have the responsibility to deliver fair, impartial
            rulings and to assist the head judge and other tournament officials in any area that is required to
            ensure a smooth tournament. Judges must take action to resolve any rules infraction (whether a violation
            of the VEKN Tournament Rules or the game rules) they notice or that is brought to their attention.
        </p>
        <h3 id="H2-6-head-judge-responsibilities">2.6. Head Judge Responsibilities
            <a class="link-secondary" rel="bookmark" href="#H2-6-head-judge-responsibilities">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Officially sanctioned competition requires the physical
            presence of a head judge during play to adjudicate disputes, interpret rules, assign penalties, and make
            other official decisions. The head judge may, with the tournament organizer's agreement, appoint any
            number of other judges to help in the performance of the head judge's duties and to perform other tasks
            the head judge may require. The head judge is responsible for reporting all warnings issued at the
            tournament to the VEKN either directly or through the tournament organizer's event report.
        </p>
        <p>
            The head judge and the tournament organizer can be, but do not
            have to be, the same individual. The head judge is the final judicial authority at any VEKN-sanctioned
            tournament (see <a href="#H2-5-judge-responsibilities">2.5. Judge Responsibilities</a>).
        </p>
        <h3 id="H2-7-appeals-to-the-head-judge">2.7. Appeals to the Head Judge
            <a class="link-secondary" rel="bookmark" href="#H2-7-appeals-to-the-head-judge">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            If players should disagree with a judge's decision, they are
            free to appeal the ruling to the head judge. The head judge has the right to overrule other judges'
            decisions. Players may not appeal to the head judge before the judge responding to the situation renders
            an initial decision. The head judge's decision is final.
        </p>
        <h3 id="H2-8-lengthy-rulings">2.8. Lengthy Rulings
            <a class="link-secondary" rel="bookmark" href="#H2-8-lengthy-rulings"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            If a judge uses more than one minute to make a ruling, he or
            she may extend the game time appropriately. The extra time must be clearly communicated and recorded
            immediately by the judge.
        </p>
        <h3 id="H2-9-multi-judge-system">2.9. Multi-Judge System
            <a class="link-secondary" rel="bookmark" href="#H2-9-multi-judge-system">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            The Multi-Judge System may be used at any non-qualifier,
            non-championship tournament with at least eight participants (<i>i.e.</i>, having at least two tables).
            Organizers choosing this system must announce its use before the tournament begins and identify six
            judges as head judge, secondary judge, and third, fourth, fifth, and sixth judge. Organizers should use
            good judgement when selecting the Multi-Judge System and should ensure its use will not disrupt the
            event. Tournament organizers may only participate in events they sanction if they are using the
            Multi-Judge System. These types of events are the only ones in which judges and/or tournament organizers
            are allowed to participate.
        </p>
        <p>
            When using the Multi-Judge System, the head judge makes all
            rulings, except when a decision is needed in a game in which the head judge was seated as a player. If a
            ruling is needed in a head judge's game, the secondary judge makes the call, except in games in which
            both the head judge and secondary judge were both seated, and so on. The only time the sixth judge makes
            a ruling is when the head judge, the secondary judge, and the third, fourth, and fifth judges are seated
            at a game.
        </p>
        <h2 id="H3-tournament-mechanics">3. Tournament Mechanics
            <a class="link-secondary" rel="bookmark" href="#H3-tournament-mechanics">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <h3 id="H3-1-round-structure">3.1. Round Structure
            <a class="link-secondary" rel="bookmark" href="#H3-1-round-structure"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            VTES tournaments shall consist of a minimum of three rounds. After the preliminary two or
            more rounds, the players are ranked according to the number of Game Wins (see
            <a href="#H3-7-determining-a-game-winner">3.7. Determining a Game Winner</a>). For
            players with the same number of Game Wins, the players' total accumulated Victory Points from the
            preliminary rounds are used as a tie-breaker. In the event that ties still exist, Tournament Points (see
            <a href="#H3-7-3-tournament-point-scoring">3.7.3. Tournament Point Scoring</a>) are used.
            Remaining ties for any of the top five rankings are resolved using any fair random method
            (<i>e.g.</i>, a coin toss or a die roll). The five highest-ranked players advance to the final round.
        </p>
        <h4 id="H3-1-1-round-time-limits">3.1.1. Round Time Limits
            <a class="link-secondary" rel="bookmark" href="#H3-1-1-round-time-limits">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Each round in the tournament has a time limit. The minimum time limit used in VTES rounds
            is two hours. The time limit must be announced before play begins. The final round may last longer than
            the preliminary rounds, at the judge's option.
        </p>
        <p>
            When the round is over, the judge will notify all players. The game will end with the
            current minion action - if any -, or at the end of the current phase, if the notification didn't happen
            during the minion phase.
        </p>
        <h4 id="H3-1-2-preliminary-rounds-seating">3.1.2. Preliminary Rounds Seating
            <a class="link-secondary" rel="bookmark" href="#H3-1-2-preliminary-rounds-seating">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            The judge will group players randomly and impartially, using prepared index cards, a
            computerized system for generating random groupings, or another impartial randomizing method. Regardless
            of the method used, the players are to be grouped randomly and impartially, without regard to the
            identities of the players behind the numbers (or cards or other method used to designate players in the
            system) and without regard to any personal relationship between the players or personal disposition of
            any player toward another. Use of the optimal seating chart, found in The Archon tournament tracking
            spreadsheet, is encouraged.
        </p>
        <p>
            The judge will randomly and impartially assign players in groups of five. In the event that
            the number of players is not evenly divisible by five, the judge will assign players in groups of four
            and five, such that as many groups as possible contain five players.
        </p>
        <p>
            If the players cannot be divided into groups of 4 and 5 (<i>i.e.</i>, there are 6, 7, or 11
            players), then the judge may elect to use a seating arrangement in which some players sit out each round
            (while still ensuring that every player plays the same number of games, usually equal to one less than
            the number of rounds).
        </p>
        <p>
            Each table has five positions, numbered one through five, arranged clockwise around the
            table. The first player assigned to a table occupies position one, and so on. When play begins for each
            round, the player in position one plays first (with a default of one transfer during the influence
            phase), and so on. At tables with only four players, the empty position for turn rotation is ignored.

        </p>
        <p>
            The judge must ensure that exact predator-prey relationships are not duplicated from round
            to round whenever possible. When this occurs, the judge will randomly and impartially rearrange the
            seating assignments of all players at the affected table. The judge may, at his or her discretion,
            reseat players who were assigned to table together during any previous round to different tables (doing
            so impartially).
        </p>
        <h4 id="H3-1-3-final-round-seating">3.1.3. Final Round Seating
            <a class="link-secondary" rel="bookmark" href="#H3-1-3-final-round-seating">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Table positions are not assigned in the final round. Instead each of the finalists is given
            an index card (or reasonable substitute) with his or her name on it. Each finalist shuffles his or her
            crypt and presents it to the judge for additional shuffling and cutting, if desired. The judge then
            draws three random cards from each crypt and reveals them: those, as well as the number of cards left in
            the crypt and who they belong to, are public information until all the players are seated. Starting with
            the lowest qualifier, each qualifier places his or her index card faceup in a row on the table. When
            placing his or her card, each player must choose to position his or her card at either end of the row
            (one end of the row is equivalent to the other) or may create a space between two cards already placed.
            After all cards have been placed, they are read from left to right to determine seating positions in the
            final round. The judge will then determine randomly which player will play first. The revealed crypt
            cards are shuffled back into their owner's crypt.
        </p>
        <p>
            <strong>Example</strong>:
        </p>
        <table class="table table-striped">
            <tbody>
                <tr>
                    <td>
                        <p>Player 5 (the lowest qualifier) places her card.</p>
                    </td>
                    <td>
                        <p class="text-center">5</p>
                    </td>
                </tr>
                <tr>
                    <td>
                        <p>Player 4 chooses to place his card at the right end of the row.</p>
                    </td>
                    <td>
                        <p class="text-center">5 <i class="bi bi-arrow-right"></i> 4</p>
                    </td>
                </tr>
                <tr>
                    <td>
                        <p>Player 3 chooses to place her card at the left end of the row.</p>
                    </td>
                    <td>
                        <p class="text-center">3 <i class="bi bi-arrow-right"></i> 5 <i class="bi bi-arrow-right"></i> 4
                        </p>
                    </td>
                </tr>
                <tr>
                    <td>
                        <p>
                            Player 2 chooses to create a space between players 5 and 4 and places his card in that
                            space.
                        </p>
                    </td>
                    <td>
                        <p class="text-center">
                            3 <i class="bi bi-arrow-right"></i>
                            5 <i class="bi bi-arrow-right"></i>
                            2 <i class="bi bi-arrow-right"></i>
                            4
                        </p>
                    </td>
                </tr>
                <tr>
                    <td>
                        <p>
                            Player 1 (the highest qualifier) chooses to create a space between players 2 and 4 and
                            places her card in that space.
                        </p>
                    </td>
                    <td>
                        <p class="text-center">
                            3 <i class="bi bi-arrow-right"></i>
                            5 <i class="bi bi-arrow-right"></i>
                            2 <i class="bi bi-arrow-right"></i>
                            1 <i class="bi bi-arrow-right"></i>
                            4
                        </p>
                    </td>
                </tr>
            </tbody>
        </table>
        <h4 id="H3-1-4-bowing-out-of-an-event">3.1.4. Bowing Out of an Event
            <a class="link-secondary" rel="bookmark" href="#H3-1-4-bowing-out-of-an-event">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Players choosing to leave (quit playing) an event must inform the scorekeeper before the
            seatings for the next round are generated. Players leaving the tournament after the scorekeeper begins
            seatings for the next round receive a "Loss" in the upcoming round and will be removed from the event
            after that round.
        </p>
        <h4 id="H3-1-5-multi-deck-system">3.1.5 Multi-Deck System
            <a class="link-secondary" rel="bookmark" href="#H3-1-5-multi-deck-system">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Players are prohibited from making modifications to their decks between rounds unless the
            tournament uses the following multi-deck rules. The multi-deck system can be used at any tournament that
            is neither a national championship, a grand prix, or a continental championship. Organizers choosing to
            use this system must announce its use in advance of the tournament date. Players may choose to bring any
            number of tournament-legal decks to the tournament and/or extra cards to exchange with cards in their
            decks (also known as a sideboard in some games). Between rounds, players may freely switch decks (or
            cards in their decks).
        </p>
        <h4 id="H3-1-6-tournament-without-final">3.1.6 Tournament Without Final
            <a class="link-secondary" rel="bookmark" href="#H3-1-6-tournament-without-final">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            In a very small tournament, one with fewer than 8 players (<i>i.e.</i>, fewer than two
            tables), the organizer may choose to omit the final round altogether or may choose to run an additional
            "preliminary" round in place of the final. This decision must be made and announced to all the players
            prior to the start of the first round. With no final, the results of the preliminary rounds (including
            the additional preliminary round, if any) are used to determine final standings in the same manner as
            described in 3.1 above. The no-final rules can be used in conjunction with or without the multi-deck
            system above, at the organizer's option. A tournament begun under the no-final arrangement cannot admit
            more players between rounds if doing so would create a round with 8 or more players.
        </p>
        <h3 id="H3-2-pre-game-procedure">3.2. Pre-Game Procedure
            <a class="link-secondary" rel="bookmark" href="#H3-2-pre-game-procedure">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            The following steps must be performed in order before each game begins.
        </p>
        <ul>
            <li>Players shuffle their decks.</li>
            <li>Players present their decks to their predators for additional shuffling and cutting, if desired.
            </li>
            <li>Each player draws seven cards from his or her library and four cards from his or her crypt.</li>
        </ul>
        <p>
            All shuffling must be done so that the faces of the cards cannot be seen. Regardless of the
            method used to shuffle, players' decks must be sufficiently randomized. Each time players shuffle their
            decks (before the game or during the game), they must present their decks to their predator for
            additional shuffling and/or cutting. At the judge's discretion, players may request to have a judge
            shuffle their cards rather than pass that duty to their predators. By presenting their decks to their
            predators, players state that their decks are sufficiently randomized.
        </p>
        <p>
            After decks are presented and accepted, players who do not consider their opponents' decks
            to be sufficiently randomized must notify a judge. The head judge has final authority regarding whether
            a deck has been sufficiently randomized.
        </p>
        <p>
            Once predators have the opportunity to shuffle and/or cut players' decks, the cards are
            returned to their original owners. If the predator has shuffled the player's deck, that player may make
            one final cut.
        </p>
        <h3 id="H3-3-tardiness">3.3. Tardiness
            <a class="link-secondary" rel="bookmark" href="#H3-3-tardiness"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Players are expected to be in their seats when each round begins. Players arriving at their
            seats after the round begins may be subject to tardiness penalties. Players who fail to arrive at their
            seats within 15 minutes of the scheduled start of a round will receive a "Loss" in the round. This
            section should not be construed to apply in the case of Late Arrivals who were not assigned a seat in a
            given round (see following section).
        </p>
        <h3 id="H3-3-1-late-arrivals">3.3.1 Late Arrivals
            <a class="link-secondary" rel="bookmark" href="#H3-3-1-late-arrivals"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Players arriving for the event after the start of the first round may, at the judge's
            discretion, be added to the event and may play in subsequent rounds. Such players may begin play at the
            start of the next round. Players may not be added to games already in progress.
        </p>
        <h3 id="H3-3-2-early-departure">3.3.2 Early Departure
            <a class="link-secondary" rel="bookmark" href="#H3-3-2-early-departure"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Players leaving ("dropping out of") an event before all of the preliminary rounds are
            finished must notify the judge as soon as possible. If the judge has already set seating assignments for
            the round, the judge may treat this as per
            <a href="#H3-1-4-bowing-out-of-an-event">3.1.4. Bowing Out of an Event</a> above, at his or her discretion.
        </p>
        <h3 id="H3-3-3-in-game-breaks">3.3.3 In-game Breaks
            <a class="link-secondary" rel="bookmark" href="#H3-3-3-in-game-breaks"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Players are not premitted to take breaks in the middle of a game without notifying a judge.
            Players should take any necessary personal breaks between rounds, but if it is necessary to take a break
            in the middle of a game, a judge should be called first to ensure that the proper amount of time is
            given to the game (extending the time limit for that table as needed).
        </p>
        <h3 id="H3-4-pre-game-procedure">3.4. Pre-Game Procedure
            <a class="link-secondary" rel="bookmark" href="#H3-4-pre-game-procedure">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            At the start of each game, competitors shuffle their decks and present them to their
            opponents for additional shuffling and/or cutting. Any shuffling of opponents' decks must be done in a
            timely manner before the game begins. Shuffling requirements specified in
            <a href="#H3-2-pre-game-procedure">3.2. Pre-Game Procedure</a> apply during these steps.
        </p>
        <p>
            If the head judge determines that a player uses shuffling as a stalling method, that player
            will be subject to the appropriate provisions of the
            <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a>.
        </p>
        <h3 id="H3-5-conceding-games">3.5. Conceding Games
            <a class="link-secondary" rel="bookmark" href="#H3-5-conceding-games"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Players may concede a game at any time provided all but one of the players agree to concede,
            and provided it doesn't violate the play to win rule, with the result that game is recorded as if the
            remaining player had succeeded in ousting the conceding players in sequence. Please note that players
            who attempt to bribe, coerce, or otherwise improperly induce their opponents to concede will be subject
            to the appropriate section of the <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a>.
        </p>
        <h3 id="H3-6-intentional-draw">3.6. Intentional Draw
            <a class="link-secondary" rel="bookmark" href="#H3-6-intentional-draw"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Players may mutually agree to accept an intentional draw at any time before the game results
            are submitted. If an offer to intentionally draw is declined, the game must continue as normal without
            any further coercion to accept the offer. Declaring an intentional draw has the same results for
            competitors as playing to the time limit
            (see <a href="#H3-7-2-victory-point-scoring">3.7.2. Victory Point Scoring</a>).
        </p>
        <h3 id="H3-7-determining-a-game-winner">3.7. Determining a Game Winner
            <a class="link-secondary" rel="bookmark" href="#H3-7-determining-a-game-winner">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            There are three different types of scoring points in VTES tournaments:
        </p>
        <ul>
            <li>Game Wins are awarded to the winner of each game.</li>
            <li>
                Victory Points are awarded when a player's prey is ousted and when a player survives a round (or as
                otherwise specified in the game rules or by effects of cards played, but with only a half Victory
                Point awarded for withdrawal).
            </li>
            <li>Tournament Points are awarded based on a player's table ranking at the end of a round.</li>
        </ul>
        <h3 id="H3-7-1-game-win-scoring">3.7.1. Game Win Scoring
            <a class="link-secondary" rel="bookmark" href="#H3-7-1-game-win-scoring">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            A player receives a Game Win at the end of a game in which they have received at least two
            (2) Victory Points and have more Victory Points than any other player in the game (no game win is
            awarded in the case of ties).
        </p>
        <h3 id="H3-7-2-victory-point-scoring">3.7.2. Victory Point Scoring
            <a class="link-secondary" rel="bookmark" href="#H3-7-2-victory-point-scoring">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            A player receives one Victory Point each time his or her prey is ousted during a game (or as
            otherwise indicated in the VTES game rules or by cards played during the game).
        </p>
        <p>
            Unlike the standard rules, however, a player receives only a half Victory Point for
            withdrawing, not the full Victory Point the normal rules award.
        </p>
        <p>
            A player receives a half Victory Point if he or she has not been ousted when the time limit
            is reached, marking the end of the round, unless that player is the last one surviving at the table, in
            which case (as indicated in the VTES game rules) the player receives a full Victory Point, as normal.

        </p>
        <p>
            With all the Victory Points recorded, players are then ranked at their table from first
            through fifth place. The player with the highest total Victory Points places first, and so on.
        </p>
        <h3 id="H3-7-3-tournament-point-scoring">3.7.3. Tournament Point Scoring
            <a class="link-secondary" rel="bookmark" href="#H3-7-3-tournament-point-scoring">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Five-player table: First place receives 60 Tournament Points, second place receives 48
            Tournament Points, third place receives 36 Tournament Points, fourth place receives 24 Tournament
            Points, and fifth place receives 12 Tournament Points.
        </p>
        <p>
            Four-player table: Players are ranked first, second, fourth, and fifth - third place is
            taken by the "table bye" position, an empty position.
        </p>
        <p>
            If more than one player is tied for a particular table ranking, the tournament points are
            averaged (see following section).
        </p>
        <h3 id="H3-7-4-scoring-examples">3.7.4. Scoring Examples
            <a class="link-secondary" rel="bookmark" href="#H3-7-4-scoring-examples">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            <strong>Example (five-player table):</strong> Players A and C ousted one prey each. Players B and D
            were ousted by A and C, and did not oust any prey during the game. Player E did not oust any prey, but
            survived the round (along with A and C).
        </p>
        <p>
            Therefore, Players A and C each receive one and one-half Victory Points - one Victory Point
            for ousting one prey, and one-half Victory Point for surviving the round. Player E receives one-half
            Victory Point for surviving the round. Players B and D receive no Victory Points.
        </p>
        <p>
            Players A and C tie for first place (first and second) at the table, so each receives 54
            Tournament Points ([60 + 48] / 2 = 54). Since they are tied (and since neither scored at least 2 Victory
            Points), no Game Win is awarded. Player E is clearly in third place, and receives 36 Tournament Points.
            Players B and D tie for fourth (fourth and fifth) place, and each receives 18 Tournament Points ([24 +
            12] /2 = 18).
        </p>
        <p>
            <strong>Example 2 (four-player table): </strong>Player A ousts one prey and survives the round. Player
            B was ousted by Player A. Players C and D did not oust any prey during the game, but both survived the
            round.
        </p>
        <p>
            Therefore, Player A receives one and one-half Victory Points - one Victory Point for ousting
            one prey, and one-half Victory Point for surviving the round. Player B receives no Victory Points, and
            Players C and D each receive one-half Victory Points for surviving the round.
        </p>
        <p>
            Player A finishes in first place at the table, and receives 60 Tournament Points. Players C
            and D tie for second (second and fourth, because third place at the table goes to the "table bye"), and
            each receive 36 Tournament Points ([48 + 24] / 2 = 36). Player B finishes in fifth place with 12
            Tournament Points.
        </p>
        <h3 id="H3-7-5-final-round-scoring">3.7.5. Final Round Scoring
            <a class="link-secondary" rel="bookmark" href="#H3-7-5-final-round-scoring">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            The player with the highest total of Victory Points from the final round only is the
            tournament winner. In the event of a tie, the players' rankings at the end of the preliminary rounds
            will be the deciding tiebreaker. The rest of the finalists tie for second, with no additional criteria
            considered to attempt to break that tie.
        </p>
        <h2 id="H4-tournament-game-rules">4. Tournament Game Rules
            <a class="link-secondary" rel="bookmark" href="#H4-tournament-game-rules">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <h3 id="H4-1-cards-allowed">4.1. Cards Allowed
            <a class="link-secondary" rel="bookmark" href="#H4-1-cards-allowed"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            All cards in a player's deck must be genuine Vampire: The Eternal Struggle or Jyhad cards or
            official VEKN issued cards from the only authoritative source
            <a href="https://www.vekn.net/" target="_blank">www.vekn.net</a>
            as listed here:
        </p>
        <ul>
            <li>
                <a target="_blank" href="https://www.vekn.net/vampire-elder-kindred-network/246-danse-macabre">Danse
                    Macabre</a>
            </li>
            <li>
                <a target="_blank" href="https://www.vekn.net/vampire-elder-kindred-network/292-the-unaligned">The
                    Unaligned</a>
            </li>
            <li>
                <a target="_blank" href="https://www.vekn.net/vampire-elder-kindred-network/310-storyline-rewards-2015">
                    Storyline Rewards 2015
                </a>
            </li>
            <li>
                <a target="_blank" href="https://www.vekn.net/card-lists/353-anarchs-unbound-released-2">Anarchs
                    Unbound</a>
            </li>
        </ul>
        <p>
            When using VEKN issued cards they must be preferably color printed on standard paper and inserted into
            opaque sleeves before another Vampire: The Eternal Struggle or Jyhad card, this requires opaque sleeves
            for the whole crypt and/or library. <strong>These cards are not considered as proxies</strong>. See
            <a target="_blank" href="https://www.vekn.net/official-expansion-sets">official expansion sets</a>.
        </p>
        <p>
            If cards with distinct backs are used in the same deck (<i>e.g.</i>, Jyhad and Vampire: The
            Eternal Struggle cards, or upside-down 3rd Edition cards and right-side up cards, or mis-cut cards, or
            cards without the Deckmaster logo) are used, in order to prevent a significant advantage, all cards from
            the different sets, printings, etc. must be of sufficiently mixed card type, unless they are all sleeved
            with opaque sleeves (recommended).
        </p>
        <h3 id="H4-1-1-banned-list">4.1.1 Banned List
            <a class="link-secondary" rel="bookmark" href="#H4-1-1-banned-list"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            The following cards are banned in all VEKN tournaments:
        </p>
        <ul>
            <li><em>Anthelios, the Red Star</em>(Promo)</li>
            <li><em>Dramatic Upheaval</em> (VTES)</li>
            <li><em>Edge Explosion</em> (NoR)</li>
            <li><em>Gypsies</em> (VTES)</li>
            <li><em>Kindred Restructure</em> (VTES)</li>
            <li><em>Lilith's Blessing</em> (Promo)</li>
            <li><em>Madness of the Bard</em> (Dark Sovereigns)</li>
            <li><em>Memories of Mortality</em> (Ancient Hearts)</li>
            <li><em>Protect Thine Own</em> (Ancient Hearts)</li>
            <li><em>The Return to Innocence</em> (Ancient Hearts)</li>
            <li><em>Rom Gypsy</em> (Dark Sovereigns)</li>
            <li><em>Seeds of Corruption</em> (Ancient Hearts)</li>
            <li><em>Succubus Club</em> (VTES)</li>
            <li><em>Tarbaby Jack</em> (Black Hand)</li>
            <li><em>Temptation of Greater Power</em> (VTES)</li>
            <li><em>Terrorists</em> (Ancient Hearts)</li>
            <li><em>Tsigane</em> (Dark Sovereigns)</li>
            <li>Any cards that are usable only when playing for ante, including:
                <ul>
                    <li><em>Cunctator Motion</em> (VTES)</li>
                    <li><em>High Stakes</em> (VTES)</li>
                    <li><em>Playing for Keeps</em> (Dark Sovereigns)</li>
                </ul>
            </li>
        </ul>
        <p>
            Note that rules cards from Nights of Reckoning are legal for VEKN play in both Constructed
            and Limited formats.
        </p>
        <h3 id="H4-2-card-interpretation">4.2. Card Interpretation
            <a class="link-secondary" rel="bookmark" href="#H4-2-card-interpretation">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            The head judge is the final authority regarding card interpretations. All cards are to be
            interpreted according to their most recent printing. If the head judge determines that a player is using
            older cards and/or misprints to create an advantage by using misleading text or artwork, that player
            will be subject to the appropriate provisions of the
            <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a>.
        </p>
        <h3 id="H4-3-new-releases">4.3. New Releases
            <a class="link-secondary" rel="bookmark" href="#H4-3-new-releases"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            New VTES cards and rules (new expansions, new editions of the basic set, new rules released
            in expansions or basic sets, and promotional cards) are allowed in Constructed tournament play beginning
            30 days after their retail release date. VEKN announcements confirm the exact date that each new card
            set enters tournament play before the set is released.
        </p>
        <p>
            New cards or rules are allowed in Limited tournament play immediately, including before the
            release date (for example, at a Prerelease tournament).
        </p>
        <h3 id="H4-4-card-elevation-and-disposition">4.4. Card Elevation and Disposition
            <a class="link-secondary" rel="bookmark" href="#H4-4-card-elevation-and-disposition">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Players must keep their cards above the level of the playing surface. Revealing cards in
            your hand or uncontrolled area to any opponent is not allowed.
        </p>
        <h3 id="H4-5-proxy-cards">4.5. Proxy Cards
            <a class="link-secondary" rel="bookmark" href="#H4-5-proxy-cards"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            As long as the game is not under production, the organizer of an event that is neither a
            National Championship nor a Continental Championship can choose to allow proxy cards in his or her
            event. For events where proxy cards are allowed, several points apply:
        </p>
        <ul>
            <li>there are no limit to the number of proxy cards a deck can have</li>
            <li>every proxy card must be a color-copy of the original card, on standard paper</li>
            <li>the quality of the print must allow the reading of the illustrator's name</li>
            <li>the organizer must mark the event as 'allowing proxy cards' on the VEKN calendar"</li>
        </ul>
        <p>
            Proxy-cards must be inserted in an opaque sleeve (along the rest of the crypt and/or library),
            before a regular VTES card.
        </p>
        <p>
            Otherwise, the use of proxy cards is not permitted, unless a judge provides these cards. If
            a card becomes excessively worn through play or accidentally damaged in the current sanctioned
            tournament, or if the owner of the card must leave prior to the conclusion of a game, the judge may
            provide a proxy replacement card or (in the case of damaged or worn cards) require the player to sleeve
            all of his or her cards before play continues.
        </p>
        <p>
            When a judge creates a proxy for a player, it is included in the player's deck. The original
            card is kept close at hand during the game, if possible. When the proxy is in play, replace it with the
            original. When it returns to the player's deck/hand, swap it with the proxy. This replacement method
            helps ensure that the opponent is able to clearly see the intended card and to avoid confusion.
        </p>
        <p>
            The term "proxy" includes counterfeit cards or any card that is not a genuine game card.
            Counterfeiters will be prosecuted to the fullest extent of the law.
        </p>
        <h3 id="H4-6-card-sleeves">4.6. Card Sleeves
            <a class="link-secondary" rel="bookmark" href="#H4-6-card-sleeves"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Players may use plastic card sleeves or other protective devices on cards. If a player
            chooses to use card sleeves, all cards in the player's current deck must be placed in the sleeves in an
            identical manner. If the sleeves feature holograms or other markings, cards must be inserted into the
            sleeves so these markings appear uniformly on the cards (all markings on the face or all on the backs,
            but not mixed). A player may choose to sleeve his library but not his crypt, or vice-versa, and the
            crypt and the library may be sleeved differently from each other.
        </p>
        <p>
            Once a game begins, players may request that the judge inspect an opponent's card sleeves.
            The judge may disallow a player's card sleeves if the judge believes they are marked, worn, or otherwise
            in a condition that interferes with shuffling or game play. To avoid confusion, a card sleeve may also
            be used to mark a player's card if the card is in an opponent's playing area.
        </p>
        <h3 id="H4-7-locked-cards">4.7. Locked Cards
            <a class="link-secondary" rel="bookmark" href="#H4-7-locked-cards"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            If a card must be locked as a part of the game rules, it must be turned approximately 90
            degrees from the normal position.
        </p>
        <h3 id="H4-8-play-to-win">4.8. Play to Win
            <a class="link-secondary" rel="bookmark" href="#H4-8-play-to-win"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            One aspect of sportsmanlike conduct is that players must not play toward goals that conflict
            with the goal of the game as stated in the VTES rulebook (<i>e.g.</i>, attacking certain players on the
            basis of their VEKN ratings or overall tournament standing, etc.). For tournaments, playing to win
            means playing to get a Game Win if it is reasonably possible, and when a Game Win is not reasonably
            possible, then playing to get as many Victory Points as possible.
        </p>
        <p>
            Neither the basic game rules nor the tournament rules enforce or regulate deals made between
            players. The tournament rules acknowledge deals, however, in that a deal which represents the best
            interests of the players involved at the time the deal is made is allowed to be honored, even when the
            normal play to win rule would indicate that a deal should be broken. This only applies to deal that are
            in the best interests of the players involved at the time the deal is made. That is, it applies only
            when making the deal is playing to win. (It is also allowable to break such a deal, of course).
        </p>
        <p>
            During the finals, playing to win means playing to finish as tournament winner (as defined
            in <a href="#H3-7-5-final-round-scoring">3.7.5. Final Round Scoring</a>).
        </p>
        <p>
            <strong>Exception:</strong> when only two Methuselahs remain, the tournament rules no longer
            acknowledge any deals. Prior deals are voided, even if they were play to win when made. When only two
            Methuselahs remain, both Methuselahs must play to win based only on game state, without regard to any
            deals.
        </p>
        <h3 id="H4-9-infinite-loops">4.9. Infinite Loops
            <a class="link-secondary" rel="bookmark" href="#H4-9-infinite-loops"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            When a loop is detected (meaning game state has been completely restored to a previous state
            and could be repeated without limit except for the round's time limit), the activity cannot be begun
            again (until and unless game state changes). This includes actions, sequences of combats, rounds of
            combat, and everything else. Note that game state includes all players' hands, ash heaps, and libraries,
            as well as available maneuvers and presses from cards in play, and master: out-of-turn plays.
        </p>
        <h2 id="H5-tournament-violations">5. Tournament violations
            <a class="link-secondary" rel="bookmark" href="#H5-tournament-violations">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <h3 id="H5-1-cheating">5.1. Cheating
            <a class="link-secondary" rel="bookmark" href="#H5-1-cheating"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Cheating will not be tolerated. The head judge reviews all cheating allegations, and if he
            or she determines that a player cheated, the head judge will issue the appropriate penalty based on the
            <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a>. All disqualifications are subject to
            later VEKN review, and further penalties may be assessed.
        </p>
        <p>
            Cheating includes, but is not limited to, the following intentional activities:
        </p>
        <ul>
            <li>Receiving outside assistance or coaching</li>
            <li>Looking at opponents' card faces while shuffling or cutting their decks</li>
            <li>Collusion to alter the results of a game</li>
            <li>Misrepresenting rules or card texts or errata</li>
            <li>Using marked cards/sleeves (see section 4.6)</li>
            <li>Drawing extra cards</li>
            <li>Manipulating which cards are drawn from your deck or from an opponent's deck</li>
            <li>Stalling to take advantage of a time limit</li>
            <li>Misrepresenting or obscuring public information (pool totals, number of cards in deck, and so on)
            </li>
        </ul>
        <h3 id="H5-2-unsportsmanlike-conduct">5.2. Unsportsmanlike Conduct
            <a class="link-secondary" rel="bookmark" href="#H5-2-unsportsmanlike-conduct">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Unsportsmanlike conduct is unacceptable and will not be tolerated at any time. Players who
            engage in unsportsmanlike conduct will be subject to the appropriate provisions of the
            <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a> and the
            <a href="{{ url_for('document_code_of_ethics') }}">VEKN Code of Ethics</a>, and
            will be subject to further VEKN review. Judges, players, spectators, and officials must
            behave in a polite, respectable, and sportsmanlike manner. In addition, players must not use profanity,
            argue, act belligerently toward tournament officials or one another, or harass spectators, tournament
            officials, or opponents. See also <a href="#H4-8-play-to-win">4.8. Play to Win</a> above.
        </p>
        <h3 id="H5-3-slow-play">5.3. Slow Play
            <a class="link-secondary" rel="bookmark" href="#H5-3-slow-play"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Players must take their turns in a timely fashion. Whereas taking a reasonable amount of
            time to think through game strategy is acceptable, playing excessively slowly or stalling for time is
            not. If a judge determines that a player is stalling for time or playing excessively slowly at any point
            during the tournament, the responsible player will be subject to the appropriate provisions of the
            <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a>.
        </p>
        <h3 id="H5-4-marked-cards">5.4. Marked Cards
            <a class="link-secondary" rel="bookmark" href="#H5-4-marked-cards"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            A card is considered marked if it bears something that makes it possible to identify the
            card without seeing its face, including scratches, discoloration, unnatural bends, and so on. If a
            player's cards are sleeved, the sleeves are considered part of the cards, so:
        </p>
        <ul>
            <li>
                For cards placed in clear sleeves, both the sleeve and the card must be examined to determine
                whether a card is marked.
            </li>
            <li>
                For cards placed in opaque-backed sleeves, just the sleeve must be examined to determine whether a
                card is marked or not.
            </li>
        </ul>
        <p>
            If the head judge determines that a card in a player's deck is marked, that player will be
            subjected to the appropriate provisions of the
            <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a>.
        </p>
        <h2 id="H6-constructed-tournament-rules">6. Constructed Tournament Rules
            <a class="link-secondary" rel="bookmark" href="#H6-constructed-tournament-rules">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <h2 id="H6-1-constructed-formats">6.1. Constructed formats
            <a class="link-secondary" rel="bookmark" href="#H6-1-constructed-formats">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <p>
            The VEKN sanctions only one constructed format: Standard Constructed.
        </p>
        <h3 id="H6-1-1-set-restrictions">6.1.1. Set Restrictions
            <a class="link-secondary" rel="bookmark" href="#H6-1-1-set-restrictions">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            The tournament organizer may limit players to the use of one or more card sets. For example,
            the tournament organizer may require players to restrict their decks to cards from the Dark Sovereigns
            and Final Nights card sets. The tournament organizer must advertise any card set restrictions prior to
            the event. All cards will be required to use the most recent card texts even if the revised card text
            appears in a set not allowed in the current event. Example: In an event restricted to the use of the
            VTES base set, the Master card "Misdirection" would still lock only one minion.
        </p>
        <p>
            <strong>Note:</strong> Sanctioned tournaments conducted with card set restrictions will not have their
            results included in the VEKN player ratings.
        </p>
        <h3 id="H6-2-constructed-deck-size-limits">6.2. Constructed Deck Size Limits
            <a class="link-secondary" rel="bookmark" href="#H6-2-constructed-deck-size-limits">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Standard Constructed decks must contain a minimum of sixty cards and a maximum of ninety
            cards. The crypt must contain a minimum of twelve cards.
        </p>
        <h3 id="H6-3-constructed-deck-registration">6.3. Constructed Deck Registration
            <a class="link-secondary" rel="bookmark" href="#H6-3-constructed-deck-registration">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            The head judge or tournament organizer may require players to register their decks upon
            arrival at a tournament. Registration records the original composition of each deck. Once a tournament
            official receives a player's decklist, the deck may not be altered. Failure to properly register a deck
            will result in the head judge applying the appropriate provisions of the
            <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a>. The
            VEKN recommends that organizers check a reasonable number of decks against their decklists each round.

        </p>
        <h2 id="H7-limited-tournament-rules">7. Limited Tournament Rules
            <a class="link-secondary" rel="bookmark" href="#H7-limited-tournament-rules">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <p>
            The rules in this section apply to all Limited tournaments, including Sealed-Deck tournaments
            and Draft tournaments (see following section).
        </p>
        <h3 id="H7-1-limited-formats">7.1. Limited Formats
            <a class="link-secondary" rel="bookmark" href="#H7-1-limited-formats"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            The VEKN sanctions the following <strong>Sealed</strong> formats:
        </p>
        <ul>
            <li><a href="#H7-3-standard-sealed-deck-tournament-rules">7.3. Standard Sealed Deck Tournament Rules</a>
            </li>
            <li><a href="#H7-4-restricted-trade-tournament-rules">7.4. Restricted Trade Tournament Rules</a></li>
        </ul>
        <p>
            The VEKN sanctions the following <strong>Draft</strong> formats:
        </p>
        <ul>
            <li><a href="#H7-6-booster-draft-procedure">7.6. Booster Draft Procedure</a></li>
            <li>
                <a href="#H7-7-table-draft-rochester-draft-procedure">7.7. Table Draft (Rochester Draft) Procedure</a>
            </li>
            <li><a href="#H7-8-mixed-draft-elder-draft-procedure">7.8. Mixed Draft (Elder Draft) Procedure</a></li>
        </ul>
        <p>
            The VEKN sanctions some alternative <strong>Constructed</strong> formats:
        </p>
        <ul>
            <li><a href="#H7-9-restricted-format">7.9. Restricted format</a></li>
        </ul>
        <h3 id="H7-2-general-limited-format-rules">7.2. General Limited Format Rules
            <a class="link-secondary" rel="bookmark" href="#H7-2-general-limited-format-rules">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <h4 id="H7-2-1-limited-deck-composition">7.2.1. Limited Deck Composition
            <a class="link-secondary" rel="bookmark" href="#H7-2-1-limited-deck-composition">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            The minimum sizes for the library and the crypt in limited formats are determined by the
            number of boosters used per player. If any starters are used, the minimums are forty for the library and
            twelve for the crypt.
        </p>
        <p>
            If eight or more boosters are used per player, the library minimum is forty. Otherwise, the
            minimum for the library is five cards per booster, and see <a href="#H7-2-2-recursion">7.2.2. Recursion</a>
            below for the mechanism used to increase the effective size of the library.
        </p>
        <p>
            In all cases, the library cannot contain more than ninety cards.
            If twelve or more boosters are used per player, the crypt minimum is twelve. Otherwise, the
            minimum for the crypt is equal to the number of booster packs used per player.
        </p>
        <p>
            Crypts may contain cards from any groups without any limitations based on group numbers.
        </p>
        <p>
            <strong>Note:</strong> The rules based on number of boosters assume that each booster pack has eleven cards.
            When using boosters from the sets that don't have eleven cards in each booster (<em>e.g.</em>, the
            original 1994 and 1995 base sets, or from the <em>Dark Sovereigns</em>, <em>Ancient Hearts</em>,
            or <em>The Sabbat</em> expansions), then calculate the effective number of 11-card-boosters by dividing the
            total number of cards by 11 (rounded to the nearest whole number). Use that number to find the minimum
            deck sizes (this section) and the number of recursions (next section).
        </p>
        <h4 id="H7-2-2-recursion">7.2.2. Recursion
            <a class="link-secondary" rel="bookmark" href="#H7-2-2-recursion"><i class="bi bi-link-45deg"></i></a>
        </h4>
        <p>
            When the minimum library size is less than forty, each player gets a number of recursions
            based on that minimum size. (The term recursion is based on the draft format which inspired it, the
            <em>Internal Recursion Draft</em> format, also known as <em>Swainbank Draft</em>).

        </p>
        <p>
            Each recursion allows the player to use a discard phase action to shuffle all the library
            cards in his or her ash heap back into his or her library. This can be done whether or not there are any
            cards left in the player's library or hand. A player is not considered to have exhausted his or her
            library if he or she has any recursions remaining (which means that a player cannot attempt to withdraw
            if he or she has any recursions left, for instance).
        </p>
        <p>
            The number of recursions is chosen to make the effective library size (the size of the
            library multiplied by the number of times the player goes through the library) as close to sixty as
            possible. The following table shows the number of recursions each player gets based on the number of
            booster packs used per player.
        </p>
        <table class="table table-striped">
            <thead>
                <tr>
                    <th scope="col">Boosters</th>
                    <th scope="col">Minimum Crypt</th>
                    <th scope="col">Minimum Library</th>
                    <th scope="col">Recursions</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <td>12+</td>
                    <td>12</td>
                    <td>40</td>
                    <td>0</td>
                </tr>
                <tr>
                    <td>11</td>
                    <td>11</td>
                    <td>40</td>
                    <td>0</td>
                </tr>
                <tr>
                    <td>10</td>
                    <td>10</td>
                    <td>40</td>
                    <td>0</td>
                </tr>
                <tr>
                    <td>9</td>
                    <td>9</td>
                    <td>40</td>
                    <td>0</td>
                </tr>
                <tr>
                    <td>8</td>
                    <td>8</td>
                    <td>40</td>
                    <td>0</td>
                </tr>
                <tr>
                    <td>7</td>
                    <td>7</td>
                    <td>35</td>
                    <td>1</td>
                </tr>
                <tr>
                    <td>6</td>
                    <td>6</td>
                    <td>30</td>
                    <td>1</td>
                </tr>
                <tr>
                    <td>5</td>
                    <td>5</td>
                    <td>25</td>
                    <td>1</td>
                </tr>
                <tr>
                    <td>4</td>
                    <td>4</td>
                    <td>20</td>
                    <td>2</td>
                </tr>
                <tr>
                    <td>3</td>
                    <td>3</td>
                    <td>15</td>
                    <td>3</td>
                </tr>
                <tr>
                    <td>2</td>
                    <td>2</td>
                    <td>10</td>
                    <td>5</td>
                </tr>
                <tr>
                    <td>1</td>
                    <td>1</td>
                    <td>5</td>
                    <td>11</td>
                </tr>
            </tbody>
        </table>
        <p>
            Note that sixty is used for the effective library size rather than forty, because players
            will typically want to use recursion before their hands are empty, and because some library cards may be
            in play area or may have been removed from the game during play (and therefore not returned to the
            library by recursion).
        </p>
        <h4 id="H7-2-3-limited-deck-registration">7.2.3. Limited Deck Registration
            <a class="link-secondary" rel="bookmark" href="#H7-2-3-limited-deck-registration">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            The head judge or tournament organizer may require players to record on a decklist every
            card they receive in a Limited tournament. Once the cards are registered, players have a limited amount
            of time to prepare their decks before play begins. The VEKN recommends that organizers check a
            reasonable number of decks against their decklists each round.
        </p>
        <h4 id="H7-2-4-card-use-limited-tournaments">7.2.4. Card Use - Limited Tournaments
            <a class="link-secondary" rel="bookmark" href="#H7-2-4-card-use-limited-tournaments">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            All cards players use in Limited events must be received directly from tournament officials.
            Every player receives identical sealed product (same number and assortment of booster packs as every
            other player in the tournament), with the possible exception of preconstructed starter decks. If any
            preconstructed starter decks are used, they may be distributed randomly to the players. The organizer
            may require that players use the decks they are randomly given, or may allow the players to trade
            starters amongst themselves before opening any of the sealed product (starters or boosters).
        </p>
        <p>
            Optionally, the organizer may have the players bring their own sealed product, with whatever
            restriction to set(s) and/or number of boosters and/or starters from each set the organizer chooses.
            These restrictions must be advertised well in advance of the tournament. In these cases, the players
            won't necessarily have identical product.
        </p>
        <p>
            Players may use only the actual cards they receive or draft at a Limited tournament plus any
            additional cards specifically provided by the tournament organizer. Players may not trade or replace the
            cards they receive or draft at a Limited tournament with any other cards, even if the replacement is an
            exact copy. If a card is damaged or otherwise considered "marked," players must comply with the
            following section.
        </p>
        <h4 id="H7-2-5-abnormal-cards-or-boosters">7.2.5. Abnormal Cards or Boosters
            <a class="link-secondary" rel="bookmark" href="#H7-2-5-abnormal-cards-or-boosters">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Players who have an abnormal number of cards in the decks or booster packs they receive must
            inform the head judge, who may replace the deck or booster pack at his or her discretion. If a player
            receives a "marked" card (see <a href="#H5-4-marked-cards">5.4. Marked Cards</a>),
            the head judge may replace that card with a proxy card at his or her discretion
            (see <a href="#H4-5-proxy-cards">4.5. Proxy Cards</a>).
        </p>
        <p>
            Neither White Wolf nor the tournament organizer guarantees any specific distribution of card
            rarities or frequency in a particular booster pack or deck.
        </p>
        <h4 id="H7-2-6-early-departure-and-late-arrivals">7.2.6. Early Departure and Late Arrivals
            <a class="link-secondary" rel="bookmark" href="#H7-2-6-early-departure-and-late-arrivals">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Once a player in a Limited tournament has received sealed product, he or she may not leave
            (withdraw from) the event prior to the conclusion of first round. If a player violates this rule, he or
            she must return the product he or she received from the organizer, and receives a "Loss" for the round
            on the official tournament record and is dropped from the tournament.
        </p>
        <p>
            Late arrivals can be added, if the organizer permits it. The added players receive product
            and build decks according to the sealed deck rules, even if the tournament is a draft. This is true even
            if there are multiple late arrivals. They can be added into the tournament in any round after they have
            completed the contstruction of their decks.
        </p>
        <h3 id="H7-3-standard-sealed-deck-tournament-rules">7.3. Standard Sealed Deck Tournament Rules
            <a class="link-secondary" rel="bookmark" href="#H7-3-standard-sealed-deck-tournament-rules">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <h4 id="H7-3-1-deck-construction">7.3.1. Deck Construction
            <a class="link-secondary" rel="bookmark" href="#H7-3-1-deck-construction">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Before tournament play begins, each player receives an assortment of sealed product. Each
            player then creates a tournament deck that meets the Sealed-Deck size requirements found in these
            rules. Players are given a set amount of time, determined by the event organizer, in which
            to construct their decks.
        </p>
        <p>
            The head judge or tournament organizer may require players to record on a decklist every
            card they intend to play in their decks. Failure to properly record the cards being played will result
            in the head judge applying the appropriate provisions of the
            <a href="{{ url_for('document_judges_guide') }}">Judge's Guide</a>.
        </p>
        <h4 id="H7-3-2-sealed-deck-swap">7.3.2. Sealed Deck Swap
            <a class="link-secondary" rel="bookmark" href="#H7-3-2-sealed-deck-swap">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            A Standard Sealed Deck event may require participants to perform a sealed-deck swap. In a
            sealed deck swap, players do not play with the decks they originally receive at the event. Instead, the
            sealed product - as well as deck-registration sheets - are handed out to all players in the event.
            Players open their decks and record the contents on their deck-registration sheets. This process is
            called "registering a deck". A tournament official will then collect the sealed product and the
            corresponding deck-registration sheets. Next, 10 to 20 percent of the decks are handed back out to the
            players who registered them. The remainder of the decks are handed out randomly to all players who do
            not have a deck. It is perfectly acceptable for players to receive their original decks back at this
            point. This entire process is called a sealed-deck swap. Players will then construct decks from the
            product they have at this time.
        </p>
        <h3 id="H7-4-restricted-trade-tournament-rules">7.4. Restricted Trade Tournament Rules
            <a class="link-secondary" rel="bookmark" href="#H7-4-restricted-trade-tournament-rules">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Restricted Trade (also known as Michigan Draft) follows all the rules for Standard Sealed
            (see <a href="#H7-3-standard-sealed-deck-tournament-rules">7.3. Standard Sealed Deck Tournament Rules</a>),
            with the following changes:
        </p>
        <h4 id="H7-4-1-preparation-for-trade">7.4.1. Preparation for Trade
            <a class="link-secondary" rel="bookmark" href="#H7-4-1-preparation-for-trade">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            <strong>Library Cards:</strong> Each player constructs a library cards as normal, except that it must
            contain exactly 50 cards. Each player then selects 15 cards from his or her remaining (unused) library
            cards; these cards form the player's trade stock.
        </p>
        <p>
            <strong>Crypt Cards:</strong> Each player constructs an initial crypt of 10 cards. The remaining crypt
            cards are kept as a sideboard. After the trading phase, each player will take two crypt cards from his
            or her sideboard to put into his or her crypt, bringing the crypt size up to the standard 12 cards
            (after which the sideboard is put away - the cards remaining in it cannot be used for the rest of the
            tournament).
        </p>
        <h4 id="H7-4-2-player-distribution">7.4.2. Player Distribution
            <a class="link-secondary" rel="bookmark" href="#H7-4-2-player-distribution">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            With their initial libraries, crypts, trading stock, and crypt sideboards, the players
            assemble randomly into trading circles (called pods) of four to five players. Pods may correspond to the
            Players' first round table assignments.
        </p>
        <h4 id="H7-4-3-trading-procedure">7.4.3. Trading Procedure
            <a class="link-secondary" rel="bookmark" href="#H7-4-3-trading-procedure">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Players in a trading pod place the library cards in their trading stock faceup in front of
            them.
        </p>
        <p>
            The player trading first from the cards presented on the table is called the active player.
            The first active player is the participant in the first seat, designated by the judge. After each
            successful (accepted) trade, the player to the left of the active player becomes the active player.
        </p>
        <p>
            The active player offers a trade by selecting a faceup card in front of another player in
            the pod. The owner of the selected card may accept or decline the offer, with the following results:
        </p>
        <ul>
            <li>
                <strong>Accept.</strong> The owner of the selected card selects a faceup card in front of the active
                player. The two selected cards are exchanged and placed facedown.
            </li>
            <li>
                <strong>Decline.</strong> The owner of the selected card turns the selected card facedown where it is.
                The active player cannot select any other cards from the same player again this turn.
            </li>
        </ul>
        <p>
            If the active player has no faceup cards, or if all other players decline to trade with the
            active player, then his or her turn is over and the player to his or her left becomes the new active
            player.
        </p>
        <p>
            If only one player has any faceup cards, he or she turns them facedown.
        </p>
        <p>
            Once all cards are facedown, the trading phase ends. The players then add two cards from
            their crypt sideboards to their crypts and shuffle their 15 trading stock cards into their libraries
            (bringing the libraries to 65 cards). Once all pods have finished the trading phase, regular tournament
            play begins.
        </p>
        <h3 id="H7-5-general-draft-tournament-rules">7.5. General Draft Tournament Rules
            <a class="link-secondary" rel="bookmark" href="#H7-5-general-draft-tournament-rules">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <h4 id="H7-5-1-player-distribution">7.5.1. Player Distribution
            <a class="link-secondary" rel="bookmark" href="#H7-5-1-player-distribution">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Players assemble randomly into drafting circles (called pods) of roughly equal size at the
            discretion of the tournament organizer or head judge. Pods may correspond to the Players' first round
            table assignments. A tournament official then distributes the booster packs to be drafted to each player
            in the pod.
        </p>
        <p>
            As players draft the cards, they must place their cards in two orderly piles in front of
            them, one for library cards and one for crypt cards. Drafted cards may only be reviewed between the
            drafting of packs.
        </p>
        <h4 id="H7-5-2-draft-format">7.5.2. Draft Format
            <a class="link-secondary" rel="bookmark" href="#H7-5-2-draft-format"><i class="bi bi-link-45deg"></i></a>
        </h4>
        <p>
            The organizer chooses the format for the draft (table draft, booster draft, etc.). The
            organizer may choose different formats for each sealed product, and may choose to use some of the
            product in a "sealed deck" format rather than drafting it. For example, the organizer may specify that
            players will use preconstructed starters as sealed deck and then add cards from two booster packs (per
            player) drafted using booster draft rules.
        </p>
        <h4 id="H7-5-3-draft-card-selection">7.5.3. Draft Card Selection
            <a class="link-secondary" rel="bookmark" href="#H7-5-3-draft-card-selection">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Before the tournament begins, the head judge must announce how much time each player has to
            select a card. If a player fails to select a card in the time given, the pod judge issues that player a
            random card from the cards from which the player is selecting.
        </p>
        <h4 id="H7-5-4-deck-construction">7.5.4. Deck Construction
            <a class="link-secondary" rel="bookmark" href="#H7-5-4-deck-construction">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            Once drafting is complete, players are given a set amount of time, determined by the event
            organizer, in which to construct their decks from the cards they drafted. The decks must be constructed
            according to the specifications of the
            <a href="#H7-2-general-limited-format-rules">7.2. General Limited Format Rules</a>.
            The head judge or tournament organizer may require players to record on a decklist every card they intend to
            use in their decks, as well as all cards they drafted.
        </p>
        <h3 id="H7-6-booster-draft-procedure">7.6. Booster Draft Procedure
            <a class="link-secondary" rel="bookmark" href="#H7-6-booster-draft-procedure">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            At a signal from a tournament official, each player opens the booster pack specified by the
            official and counts the cards. If a player does not have the appropriate number of cards in his or her
            booster pack, he or she must notify the judge immediately, who will replace the pack. The player chooses
            one card from the booster pack, then passes the remaining cards facedown to the player on his or her
            left. The opened packs are passed around the drafting pod - with each player taking one card each before
            passing - until all cards are drafted. Once a player has removed a card from the pack, it is considered
            selected and may not be returned to the pack.
        </p>
        <p>
            After each player's first pack is drafted, a tournament official will instruct players to
            open the next specified pack and draft in the same fashion, except that the direction of drafting is
            reversed. This process is repeated until all cards in all booster packs are drafted. For example, if
            five booster packs were being drafted, the first, third, and fifth pack would be drafted clockwise and
            the second and fourth pack would be drafted counterclockwise.
        </p>
        <h3 id="H7-7-table-draft-rochester-draft-procedure">7.7. Table Draft (Rochester Draft) Procedure
            <a class="link-secondary" rel="bookmark" href="#H7-7-table-draft-rochester-draft-procedure">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Before the tournament begins, the head judge must announce how much time each player has to
            select a card. If a player fails to select a card in the time given, the pod judge issues that player
            the "oldest" card still remaining from the booster pack.
        </p>
        <p>
            <strong>Example:</strong> The pod players each lay out cards two cards from his or her booster pack.
            The cards can be considered to be in chronological order (1-10), where 1 is the first card placed on the
            table by the player who will draft first and 10 is the last card placed on the table by the player who
            will draft fifth. If a player fails to draft in a timely manner, the cards on the table are examined by
            the pod judge and the "oldest" card on the table (not yet drafted) is given to the player.
        </p>
        <p>
            During a Table Draft, players must always display the most recent card they drafted from the
            current set faceup. When all cards are drafted from the current set, players may move their cards from
            that pack to any position.
        </p>
        <h4 id="H7-7-1-table-draft-preparation">7.7.1. Table Draft Preparation
            <a class="link-secondary" rel="bookmark" href="#H7-7-1-table-draft-preparation">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            At a signal from a tournament official, each player opens the booster pack specified by the
            official and counts the cards facedown. If a player does not have the appropriate number of cards in his
            or her booster pack, he or she must notify the judge immediately, who will replace the pack. After
            counting the cards facedown to make sure the pack is correct, players then move all crypt cards to the
            top of the pack facedown.
        </p>
        <p>
            <strong>Note:</strong> some packs may have a different number of crypt cards than others.
        </p>
        <p>
            Players then place their opened packs facedown on the table in front of them. At a signal
            from the pod judge, players place the top two cards from their booster pack faceup on the table. Players
            are given twenty seconds to review the cards before drafting begins.
        </p>
        <h4 id="H7-7-2-table-draft-active-player-rotation">7.7.2. Table Draft Active Player Rotation
            <a class="link-secondary" rel="bookmark" href="#H7-7-2-table-draft-active-player-rotation">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            The player drafting first from the cards presented on the table is called the active player.
            The first active player is the participant in the first seat, designated by the judge. After all cards
            on the table have been drafted, the player to the left of the active player becomes the active player
            for the next set of cards.
        </p>
        <h4 id="H7-7-3-table-draft-order">7.7.3. Table Draft Order
            <a class="link-secondary" rel="bookmark" href="#H7-7-3-table-draft-order">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h4>
        <p>
            The draft order moves in a horseshoe pattern, beginning with the active player, continuing
            around the table to the last participant in the pod group who has not yet drafted a card. The last
            player in the group selects two cards, instead of one, and the drafting continues in reverse order,
            moving back to the player who began the drafting (the first person who drafted from the set). After all
            cards are drafted (with each player having two cards from the current set), the table judge prepares for
            the next booster-pack draft.
        </p>
        <p>
            <strong>Example:</strong> Five players are seated around a table. They are numbered 1-2-3-4-5 in a
            clockwise order. The active player is Player 1. Each player opens and counts his or her booster pack
            (facedown) and moves the crypt cards to the top. Then each player places the top two cards from his or
            her booster faceup in the center of the table. After the twenty-second review period has expired, the
            draft order is as follows:
        </p>
        <p>
            Player 1 - card 1<br> Player 2 - card 2<br> Player 3 - card 3<br> Player 4 - card 4<br>
            Player 5 - card 5<br> Player 5 - card 6<br> Player 4 - card 7<br> Player 3 - card 8<br> Player 2 - card
            9<br> Player 1 - card 10
        </p>
        <p>
            <i>Player 2 would become the active player for the next set of cards, drafting first.</i>

        </p>
        <h3 id="H7-8-mixed-draft-elder-draft-procedure">7.8. Mixed Draft (Elder Draft) Procedure
            <a class="link-secondary" rel="bookmark" href="#H7-8-mixed-draft-elder-draft-procedure">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            For mixed draft, the players in each pod open all of the packs/starters that they received
            from the tournament officials, counting the cards in each facedown to verify that each pack or starter
            is complete, and then separating the crypt cards from the library cards (both facedown). If a player
            does not have the appropriate number of cards in his or her booster pack or deck, he or she must notify
            the judge immediately, who will replace the pack or deck.
        </p>
        <p>
            After the cards are counted and split into crypt and library piles (two piles per player),
            the library cards are set aside and the crypt cards are drafted according to the
            <a href="#H7-7-table-draft-rochester-draft-procedure">7.7. Table Draft (Rochester Draft) Procedure</a>.
        </p>
        <p>
            After all crypt cards have been drafted, the crypt cards are set aside and the library cards
            are split into piles. The size of the piles is specified by the tournament organizer. Each pile is then
            treated as a separate booster, and the cards are drafted according to the
            <a href="#H7-6-booster-draft-procedure">7.6. Booster Draft Procedure</a>.
        </p>
        <h3 id="H7-9-restricted-format">7.9. Restricted format
            <a class="link-secondary" rel="bookmark" href="#H7-9-restricted-format"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            The tournament organizer can set restrictions on the content of the decks, for instance:
        </p>
        <ul>
            <li>crypts must contain only Sabbat vampires</li>
            <li>decks must contain only Black Chantry-printed cards</li>
            <li>decks must contain only Jyhad-backed cards</li>
        </ul>
        <p>
            These restrictions must be indicated in the tournament calendar.
        </p>
        <h2 id="H8-vekn-sanctioning-rules">8. VEKN Sanctioning Rules
            <a class="link-secondary" rel="bookmark" href="#H8-vekn-sanctioning-rules">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <p>
            Tournament organizers must follow the rules in this section when sanctioning events with the
            VEKN. The VEKN reserves the right to cancel sanctioning for any event at any time.
        </p>
        <h2 id="H8-1-sanctioning-deadline">8.1. Sanctioning Deadline
            <a class="link-secondary" rel="bookmark" href="#H8-1-sanctioning-deadline">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <p>
            To ensure sanctioning approval, tournament organizers must apply for VEKN sanctioning at
            least twenty-eight days prior to the event.
        </p>
        <h2 id="H8-2-sanctioned-tournament-advertising">8.2. Sanctioned Tournament Advertising
            <a class="link-secondary" rel="bookmark" href="#H8-2-sanctioned-tournament-advertising">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <p>
            Sanctioned tournaments should be announced/advertised at least twenty-eight days prior to
            the event. Announcements should include the time and place of the event.
        </p>
        <h2 id="H9-event-reporting-rules">9. Event Reporting Rules
            <a class="link-secondary" rel="bookmark" href="#H9-event-reporting-rules">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <p>
            Receiving event reports in a correct and timely manner is fundamental to accurate and
            up-to-date VEKN ratings. Tournament organizers must follow the rules outlined in this section when
            reporting their events.
        </p>
        <h3 id="H9-1-organizer-records">9.1. Organizer Records
            <a class="link-secondary" rel="bookmark" href="#H9-1-organizer-records">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Tournament organizers are required to keep copies of all tournament reports for
            VEKN-sanctioned events they run for a period of one year. These records serve as backups in case event
            results are lost.
        </p>
        <h3 id="H9-2-event-report-deadline">9.2. Event Report Deadline
            <a class="link-secondary" rel="bookmark" href="#H9-2-event-report-deadline">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Event reports are due to the VEKN within eight days of the tournament's conclusion.
            Tournament reports not received by the VEKN within eight days are considered late, and are listed in
            the VEKN tournament database as "Not Received" for fourteen days after the event.
        </p>
        <h3 id="H9-3-delinquent-tournaments">9.3. Delinquent Tournaments
            <a class="link-secondary" rel="bookmark" href="#H9-3-delinquent-tournaments">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Event reports must be received by the VEKN within thirty days of the tournament's
            conclusion. Event reports not received within fifteen to thirty days are listed as "Delinquent" in the
            VEKN tournament database. Organizers may still submit event results in this time frame without penalty.

        </p>
        <h3 id="H9-4-invalid-tournaments">9.4. Invalid Tournaments
            <a class="link-secondary" rel="bookmark" href="#H9-4-invalid-tournaments">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Players' game records at events that become invalid will not count toward their VEKN ratings and rankings.
        </p>
        <p>
            The VEKN reserves the right to invalidate reported results of any sanctioned tournament for
            any reason, but will usually do so only when fraudulent or incorrect results are reported by the
            organizer. Additionally, the VEKN reserves the right to invalidate any event reports not received
            within thirty days of the tournament date.
        </p>
        <h3 id="H9-5-event-status-updates">9.5. Event Status Updates
            <a class="link-secondary" rel="bookmark" href="#H9-5-event-status-updates">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Tournament organizers and players may check on an event's reporting status by visiting the
            VEKN website. If an organizer's event appears as "Delinquent" or "Invalid" on this report two months in
            a row, the VEKN will investigate the organizer's reporting history and issue sanctioning penalties as
            appropriate.
        </p>
        <p>
            The VEKN reserves the right to adjust penalties on an individual basis due to extenuating
            circumstances and it reserves the right to change this policy without notice.
        </p>
        <h3 id="H9-6-mandatory-vekn-numbers">9.6. Mandatory VEKN Numbers
            <a class="link-secondary" rel="bookmark" href="#H9-6-mandatory-vekn-numbers">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            All tournament participants must be assigned a VEKN membership number prior to
            participating in a sanctioned tournament. Results reported with temporary player numbers, player names,
            or placeholders will not be included in the VEKN ratings.
        </p>
        <h3 id="H9-7-tournament-reports-and-event-invitation-lists">9.7. Tournament Reports and Event Invitation Lists
            <a class="link-secondary" rel="bookmark" href="#H9-7-tournament-reports-and-event-invitation-lists">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Tournament reports must be received by the deadlines specified in the Ratings Deadline and
            Publication Schedules provided on the VEKN website. in order to be included in the ratings calculations
            used to generate invitation and bye lists (if any) for premier events.
        </p>
        <h3 id="H9-8-non-open-vtes-events">9.8. Non-Open VTES Events
            <a class="link-secondary" rel="bookmark" href="#H9-8-non-open-vtes-events">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h3>
        <p>
            Non-open VTES events are held in the following manner:
        </p>
        <ul>
            <li>
                The event coordinator outlines the qualification process and number of qualifying tournaments in a
                message to <a href="mailto:orgplay@blackchantry">orgplay@blackchantry</a> for approval.
            </li>
            <li>
                Qualifiers are handled just like regular tournaments for sanctioning, prize support, etc.,
                and are open to all players.
            </li>
            <li>
                The non-open event is sanctioned and receives prize support (possibly different than usual prize
                support) independently through direct correspondence with
                <a href="mailto:orgplay@blackchantry">orgplay@blackchantry</a>.
            </li>
        </ul>
        <h2 id="Happendix-a-vekn-rating-ranking-systems">Appendix A - VEKN Rating &amp; Ranking Systems
            <a class="link-secondary" rel="bookmark" href="#Happendix-a-vekn-rating-ranking-systems">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <p>
            The VEKN produces stats-based ratings for the VTES tournament results grouped as follows:
        </p>
        <ul>
            <li>Standard Constructed (on site)</li>
            <li>Standard Constructed Online</li>
            <li>Limited (on site, all formats together in one group)</li>
            <li>Limited Online</li>
        </ul>
        <p>
            The VEKN maintains a rating for each registered player which provides an estimate of the player's
            experience in his or her most recent VEKN sanctioned tournaments. The VEKN maintains performance
            statistics for each player as well (number of games, GW, VP).
            See the <a href="{{ url_for('index') }}">World Rankings</a> for the current ratings of prominent players.
        </p>
        <h3 id="Ha-1-the-rating">A.1 The Rating
            <a rel="bookmark" href="a-1-the-rating"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            Each player has a rating represented by a single number. This number is sometimes refered to as RtP (rating
            points).
        </p>
        <p>
            Players will be ranked according to their ratings (RtP) beginning with their first tournament. That is,
            there is no minimum number of events a player must attend before being ranked.
        </p>
        <p>
            A player will be removed from the rankings after 12 months of inactivity (no rated tournament rounds
            played), but the player's rating and other statistics will be kept indefinitely (to be used when and if the
            player plays again).
        </p>
        <h3 id="Ha-2-computing-rating">A.2 Computing Rating
            <a rel="bookmark" href="a-2-computing-rating"><i class="bi bi-link-45deg"></i></a>
        </h3>
        <p>
            The ratings system is a points accumulation system.
        </p>
        <p>
            Each player's rating is based only on sanctioned tournaments attending in the preceding 18 months. No more
            than 8 tournaments will count toward a player's rating. For players who play in more than 8 tournaments
            during a given 18 month period, only the 8 best tournament results for that player in that 18 month period
            are used.
        </p>
        <p>
            A players rating is the sum total of several values computed for each of the tournaments (up to 8
            tournaments) in which he or she plays, as described below. The most points are awarded to the players who
            finish first and second in the tournament, but all players accumulate points for games won, victory points
            achieved, and even for simply attending.
        </p>
        <ul>
            <li><strong>5 RtP</strong> for each tournament attended.</li>
            <li><strong>4 RtP</strong> for each VP (victory point) scored.</li>
            <li><strong>8 RtP</strong> for each game won (GW or final round victory).</li>
            <li>
                <strong>X RtP</strong> for finalists. X is computed based on the size (number of players) of the
                tournament and the final standing (winner or finalist) of the player. A higher bonus is awarded for
                making the finals of a Continental or National Championship than for other tournaments. See below for
                the actual computation. The players count includes disqualified players and players who left during the
                event, as long as they played at least one round.
            </li>
        </ul>
        <h4 id="Ha-2-1-finalist-bonus">A.2.1 Finalist Bonus
            <a class="link-secondary" rel="bookmark" href="#Ha-2-1-finalist-bonus"><i class="bi bi-link-45deg"></i></a>
        </h4>
        <p>
            The finalists get additional ratings points (RtPs) computed as follows. A number based on the finishing
            (winner or finalist) is multiplied by a coefficient which is designed to factor in the level of
            competition. The coefficient is based on the number of players in the tournament and the type of tournament.
        </p>
        <table class="table">
            <thead>
                <tr>
                    <th scope="col">Final Standing</th>
                    <th scope="col">Points</th>
                </tr>
            </thead>
            <tbody>
                <tr>
                    <th scope="row">Winner</th>
                    <td>90</td>
                </tr>
                <tr>
                    <th scope="row">Finalist</th>
                    <td>30</td>
                </tr>
                <tr>
                    <th scope="row">Non-finalist</th>
                    <td>0</td>
                </tr>
            </tbody>
        </table>
        <blockquote class="blockquote">
            <p>
                Coef = log<sub><small>15</small></sub>(NumPlayers<sup><small>2</small></sup>) - 1
            </p>
        </blockquote>
        <p>
            (For a 15-player tournament, the coefficient is <span class="font-monospace">1</span>.
            More players mean a larger coefficient. Fewer players mean a smaller coefficient.)
        </p>
        <p>
            For a national championship, <span class="font-monospace">0.25 </span>is added to the coefficient.<br>
            For a continental championship, <span class="font-monospace">1.0</span> is added to the coefficient.
            Grand Prix and Qualifiers get no coefficient bonus.
        </p>
        <p>
            The number of points from the table above is multiplied by the coefficient to determine the number of
            additional ratings points awarded to the finalist. For example, in a qualifier with 50 players, the
            coefficient is:
        </p>
        <blockquote class="blockquote">
            <p>log<sub><small>15</small></sub>(2500) - 1 + 0.25 = 2.889 - 0.75 = 2.139</p>
        </blockquote>
        <p>
            So the winner there gets a bonus of <span class="font-monospace">2.139 × 90 = 193</span> ratings points
            (plus normal points for winning the round and for each victory point scored).
        </p>



        <h2 id="Happendix-b-definition-of-terms">Appendix B - Definition of Terms
            <a class="link-secondary" rel="bookmark" href="#Happendix-b-definition-of-terms">
                <i class="bi bi-link-45deg"></i>
            </a>
        </h2>
        <p>
            <strong>Ante Card:</strong> Any card that mentions "ante" in the rules text of the card. These cards
            usually have a game mechanic associated with a player "anteing" a card. Ante cards are found mainly in
            older Vampire: The Eternal Struggle expansions.
        </p>
        <p>
            <strong>Banned Card:</strong> A card that is not allowed by the VEKN in the indicated format. For
            example, the card <em>Return to Innocence</em> is banned from all VEKN-sanctioned tournaments. This means
            that <em>Return to Innocence</em> is not allowed in any deck in any VEKN-sanctioned tournaments (neither
            in constructed nor in limited).
        </p>
        <p>
            <strong>Constructed:</strong> A tournament in which players bring their own decks to the tournament.
            Decks are built with any cards the player has available, subject to any restrictions given in the VEKN
            rules regarding allowable cards.
        </p>
        <p>
            <strong>Cutting:</strong> One time only, removing a single portion of a deck and placing it on top of
            the remaining portion without looking at any of the card faces. Anything more than this one cut is
            considered a shuffle.
        </p>
        <p>
            <strong>Game Begins:</strong> A game is considered to have begun once all players have presented their
            decks to their predators for shuffling/cutting.
        </p>
        <p>
            <strong>Limited:</strong> A tournament in which players build their decks at the tournament from cards
            they have received from packs opened at the tournament.
        </p>
        <p>
            <strong>Premier Events:</strong> Any event that White Wolf offers only to select tournament organizers
            or is open only to a select group of players (based on invitations, for example). Premier events can
            include, but are not limited to: World, Continental, National, Regional, or State Championships,
            storyline tournaments, and Prerelease tournaments.
        </p>
        <p>
            <strong>Promo Card:</strong> Any playable card that is released by the manufacturer separate of any
            given card set.
        </p>
        <p>
            <strong>Proxy Card:</strong> A card used during competition to represent another card; also
            counterfeit cards, or any card that is not genuinely produced by the game's manufacturer.
        </p>
        <p>
            <strong>Public Information:</strong> Refers to information that is available to all players in the
            game, such as statistics or card text that participants are required to share with tournament officials
            and opponents according to the rules of the game. For example a player's pool the number of cards in a
            player's library is public information.
        </p>
        <p>
            <strong>Rating:</strong> A numeric value published by the VEKN that indicates a player's past
            performance in sanctioned tournaments.
        </p>
        <p>
            <strong>Ranking:</strong> A value, based on a player's VEKN rating, that indicates a player's
            position relative to the group he or she is being measured against. For example, a player may be ranked
            in first place in the city of Hamburg, Germany, but may be ranked in eighty-fifth place when compared to
            all of Europe.
        </p>
        <p>
            <strong>Round: </strong>The period during which gameplay takes place.
        </p>
        <p>
            <strong>Round Begins:</strong> The time posted and/or announced by the head judge or tournament
            organizer for all players to be seated and ready for play.
        </p>
        <p>
            <strong>Scorekeeper:</strong> The scorekeeper is a tournament official whose responsibilities include:
            receiving and recording all game results, constructing player seatings, ensuring accurate entry of game
            results, removing players from the event, and so on. Tournament officials, such as the head judge or
            tournament organizer, may also be the scorekeeper for the event.
        </p>
        <p>
            <strong>Tournament Begins:</strong> Once the onsite tournament registration closes, the tournament has
            begun.
        </p>
        <p>
            <strong>Tournament Official:</strong> Any person who is empowered to maintain the tournament. This
            includes, but is not limited to: the tournament organizer, scorekeeper, other scorekeeping staff, head
            judge, and all other judges (see <a href="#H1-1-player-eligibility">1.1. Player Eligibility</a>).
        </p>
        <p>
            <strong>VEKN:</strong> The Vampire Elder Kindred Network, the VTES Players Organization responsible for
            developing and maintaining tournament rules and resources for VTES.
        </p>
        <p>
            <strong>VTES:</strong> Vampire: The Eternal Struggle, the collectible card game is document is for.
        </p>
        <div>
            <hr width="100%" size="2">
        </div>
        <p>
            The VEKN Tournament Rules are based on the applicable portions of the DCI Universal
            Tournament Rules and the DCI Vampire: The Eternal Struggle Tournament Rules for the 1999-2000 Tournament
            Season.
        </p>
        <p>
            <strong>Vampire: The Eternal Struggle</strong> is a registered trademark of Black Chantry Productions.
            <strong>Jyhad</strong> and <strong>Vampire: Elder Kindred Network</strong> are registered trademarks of
            Black Chantry Productions.
        </p>
        <p>
            © 2025 Black Chantry Productions. All rights reserved.
        </p>
    </article>
</div>
{% endblock%}