{% extends "layout.html.j2" %}

{% block scripts %}
<script async src="{{ url_for('static', path='console.js') }}" type="module"></script>
{% endblock%}

{% block content %}
<h1 class="mb-4">{{ tournament.name }}</h1>
<div id="consoleDiv" data-tournament-uid='{{ tournament.uid }}'></div>
{% endblock %}