{% extends "layout.html.j2" %}

{% block content %}
{% if message %}
<div class="alert alert-info" role="alert">{{ message | safe }}</div>
{% endif %}
<h1 class="fs-5">Login</h1>
<a type="button" class="btn btn-sm btn-discord my-2" href="{{ discord_oauth }}">
    <i class="bi bi-discord"></i>
    Discord login
</a>
<hr>
<form action="/auth/email" method="post">
    <input class="form-control me-2 mb-2" type="text" name="email" autocomplete="email" placeholder="E-mail">
    <input class="form-control me-2 mb-2" type="password" name="password" autocomplete="current-password"
        placeholder="Password">
    <div class="d-flow">
        <button type="submit" class="btn btn-primary me-2 mb-2">Login</button>
        <button type="submit" class="btn btn-secondary me-2 mb-2" formaction="/auth/email/reset">
            Reset Password
        </button>
    </div>
</form>
{% endblock %}